"""glGet* auto-generation of output arrays (DO NOT EDIT, AUTOGENERATED)"""
try:
    from OpenGL.raw.GL._lookupint import LookupInt as _L
except ImportError:
    def _L(*args):
        raise RuntimeError( "Need to define a lookupint for this api" )
_glget_size_mapping = _m = {}
# _m[0x8095] = TODO # GL_DETAIL_TEXTURE_2D_SGIS
# _m[0x809C] = TODO # GL_DETAIL_TEXTURE_FUNC_POINTS_SGIS
# _m[0x809A] = TODO # GL_DETAIL_TEXTURE_LEVEL_SGIS
# _m[0x809B] = TODO # GL_DETAIL_TEXTURE_MODE_SGIS
# _m[0x8124] = TODO # GL_DUAL_TEXTURE_SELECT_SGIS
# _m[0x8191] = TODO # GL_GENERATE_MIPMAP_SGIS
# _m[0x8182] = TODO # GL_LIST_PRIORITY_SGIX
# _m[0x85A0] = TODO # GL_PACK_SUBSAMPLE_RATE_SGIX
# _m[0x8063] = TODO # GL_PROXY_TEXTURE_1D
# _m[0x8063] = TODO # GL_PROXY_TEXTURE_1D_EXT
# _m[0x8064] = TODO # GL_PROXY_TEXTURE_2D
# _m[0x8064] = TODO # GL_PROXY_TEXTURE_2D_EXT
# _m[0x8070] = TODO # GL_PROXY_TEXTURE_3D
# _m[0x8070] = TODO # GL_PROXY_TEXTURE_3D_EXT
# _m[0x8135] = TODO # GL_PROXY_TEXTURE_4D_SGIS
# _m[0x8125] = TODO # GL_QUAD_TEXTURE_SELECT_SGIS
# _m[0x80BF] = TODO # GL_SHADOW_AMBIENT_SGIX
# _m[0x81FB] = TODO # GL_SHARED_TEXTURE_PALETTE_EXT
# _m[0x80B0] = TODO # GL_SHARPEN_TEXTURE_FUNC_POINTS_SGIS
# _m[0x8136] = TODO # GL_TEXTURE_4DSIZE_SGIS
# _m[0x8175] = TODO # GL_TEXTURE_CLIPMAP_LOD_OFFSET_SGIX
# _m[0x1003] = TODO # GL_TEXTURE_COMPONENTS
# _m[0x8147] = TODO # GL_TEXTURE_FILTER4_SIZE_SGIS
# _m[0x819D] = TODO # GL_TEXTURE_GEQUAL_R_SGIX
# _m[0x819C] = TODO # GL_TEXTURE_LEQUAL_R_SGIX
# _m[0x85A1] = TODO # GL_UNPACK_SUBSAMPLE_RATE_SGIX
_m[0x0D5B] = (1,) # GL_ACCUM_ALPHA_BITS
_m[0x0D5A] = (1,) # GL_ACCUM_BLUE_BITS
_m[0x0B80] = (4,) # GL_ACCUM_CLEAR_VALUE
_m[0x0D59] = (1,) # GL_ACCUM_GREEN_BITS
_m[0x0D58] = (1,) # GL_ACCUM_RED_BITS
_m[0x92D9] = (1,) # GL_ACTIVE_ATOMIC_COUNTER_BUFFERS
_m[0x8B89] = (1,) # GL_ACTIVE_ATTRIBUTES
_m[0x8B8A] = (1,) # GL_ACTIVE_ATTRIBUTE_MAX_LENGTH
_m[0x8259] = (1,) # GL_ACTIVE_PROGRAM
_m[0x92F5] = (1,) # GL_ACTIVE_RESOURCES
_m[0x8911] = (1,) # GL_ACTIVE_STENCIL_FACE_EXT
_m[0x8DE5] = (1,) # GL_ACTIVE_SUBROUTINES
_m[0x8E48] = (1,) # GL_ACTIVE_SUBROUTINE_MAX_LENGTH
_m[0x8DE6] = (1,) # GL_ACTIVE_SUBROUTINE_UNIFORMS
_m[0x8E47] = (1,) # GL_ACTIVE_SUBROUTINE_UNIFORM_LOCATIONS
_m[0x8E49] = (1,) # GL_ACTIVE_SUBROUTINE_UNIFORM_MAX_LENGTH
_m[0x84E0] = (1,) # GL_ACTIVE_TEXTURE
_m[0x84E0] = (1,) # GL_ACTIVE_TEXTURE_ARB
_m[0x8B86] = (1,) # GL_ACTIVE_UNIFORMS
_m[0x8A36] = (1,) # GL_ACTIVE_UNIFORM_BLOCKS
_m[0x8A35] = (1,) # GL_ACTIVE_UNIFORM_BLOCK_MAX_NAME_LENGTH
_m[0x8B87] = (1,) # GL_ACTIVE_UNIFORM_MAX_LENGTH
_m[0x9305] = (1,) # GL_ACTIVE_VARIABLES
_m[0x86A5] = (1,) # GL_ACTIVE_VERTEX_UNITS_ARB
_m[0x846E] = (2,) # GL_ALIASED_LINE_WIDTH_RANGE
_m[0x846D] = (2,) # GL_ALIASED_POINT_SIZE_RANGE
_m[0x0D1D] = (1,) # GL_ALPHA_BIAS
_m[0x0D55] = (1,) # GL_ALPHA_BITS
_m[0x8567] = (1,) # GL_ALPHA_MAX_CLAMP_INGR
_m[0x8563] = (1,) # GL_ALPHA_MIN_CLAMP_INGR
_m[0x0D1C] = (1,) # GL_ALPHA_SCALE
_m[0x0BC0] = (1,) # GL_ALPHA_TEST
_m[0x0BC1] = (1,) # GL_ALPHA_TEST_FUNC
_m[0x0BC1] = (1,) # GL_ALPHA_TEST_FUNC_QCOM
_m[0x0BC0] = (1,) # GL_ALPHA_TEST_QCOM
_m[0x0BC2] = (1,) # GL_ALPHA_TEST_REF
_m[0x0BC2] = (1,) # GL_ALPHA_TEST_REF_QCOM
_m[0x1200] = (4,) # GL_AMBIENT
_m[0x1602] = (4,) # GL_AMBIENT_AND_DIFFUSE
_m[0x8894] = (1,) # GL_ARRAY_BUFFER_BINDING
_m[0x8894] = (1,) # GL_ARRAY_BUFFER_BINDING_ARB
_m[0x81A9] = (1,) # GL_ARRAY_ELEMENT_LOCK_COUNT_EXT
_m[0x81A8] = (1,) # GL_ARRAY_ELEMENT_LOCK_FIRST_EXT
_m[0x8766] = (1,) # GL_ARRAY_OBJECT_BUFFER_ATI
_m[0x8767] = (1,) # GL_ARRAY_OBJECT_OFFSET_ATI
_m[0x92FB] = (1,) # GL_ARRAY_SIZE
_m[0x92FE] = (1,) # GL_ARRAY_STRIDE
_m[0x835D] = (1,) # GL_ASYNC_DRAW_PIXELS_SGIX
_m[0x832C] = (1,) # GL_ASYNC_HISTOGRAM_SGIX
_m[0x8329] = (1,) # GL_ASYNC_MARKER_SGIX
_m[0x835E] = (1,) # GL_ASYNC_READ_PIXELS_SGIX
_m[0x835C] = (1,) # GL_ASYNC_TEX_IMAGE_SGIX
_m[0x92C5] = (1,) # GL_ATOMIC_COUNTER_BUFFER_ACTIVE_ATOMIC_COUNTERS
_m[0x92C6] = (1,)#TODO Is actually GL_ATOMIC_COUNTER_BUFFER_ACTIVE_ATOMIC_COUNTERS # GL_ATOMIC_COUNTER_BUFFER_ACTIVE_ATOMIC_COUNTER_INDICES
_m[0x92C1] = (1,) # GL_ATOMIC_COUNTER_BUFFER_BINDING
_m[0x92C4] = (1,)#TODO Is actually GL_ATOMIC_COUNTER_BUFFER_ACTIVE_ATOMIC_COUNTERS # GL_ATOMIC_COUNTER_BUFFER_DATA_SIZE
_m[0x9301] = (1,) # GL_ATOMIC_COUNTER_BUFFER_INDEX
_m[0x90ED] = (1,)#TODO Is actually GL_ATOMIC_COUNTER_BUFFER_ACTIVE_ATOMIC_COUNTERS # GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_COMPUTE_SHADER
_m[0x92CB] = (1,)#TODO Is actually GL_ATOMIC_COUNTER_BUFFER_ACTIVE_ATOMIC_COUNTERS # GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_FRAGMENT_SHADER
_m[0x92CA] = (1,)#TODO Is actually GL_ATOMIC_COUNTER_BUFFER_ACTIVE_ATOMIC_COUNTERS # GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_GEOMETRY_SHADER
_m[0x92C8] = (1,)#TODO Is actually GL_ATOMIC_COUNTER_BUFFER_ACTIVE_ATOMIC_COUNTERS # GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_TESS_CONTROL_SHADER
_m[0x92C9] = (1,)#TODO Is actually GL_ATOMIC_COUNTER_BUFFER_ACTIVE_ATOMIC_COUNTERS # GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_TESS_EVALUATION_SHADER
_m[0x92C7] = (1,)#TODO Is actually GL_ATOMIC_COUNTER_BUFFER_ACTIVE_ATOMIC_COUNTERS # GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_VERTEX_SHADER
_m[0x92C3] = (1,)#TODO Is actually GL_ATOMIC_COUNTER_BUFFER_ACTIVE_ATOMIC_COUNTERS # GL_ATOMIC_COUNTER_BUFFER_SIZE
_m[0x92C2] = (1,)#TODO Is actually GL_ATOMIC_COUNTER_BUFFER_ACTIVE_ATOMIC_COUNTERS # GL_ATOMIC_COUNTER_BUFFER_START
_m[0x8B85] = (1,) # GL_ATTACHED_SHADERS
_m[0x8645] = (1,) # GL_ATTRIB_ARRAY_POINTER_NV
_m[0x8623] = (1,) # GL_ATTRIB_ARRAY_SIZE_NV
_m[0x8624] = (1,) # GL_ATTRIB_ARRAY_STRIDE_NV
_m[0x8625] = (1,) # GL_ATTRIB_ARRAY_TYPE_NV
_m[0x0BB0] = (1,) # GL_ATTRIB_STACK_DEPTH
_m[0x8295] = (1,) # GL_AUTO_GENERATE_MIPMAP
_m[0x0D80] = (1,) # GL_AUTO_NORMAL
_m[0x0C00] = (1,) # GL_AUX_BUFFERS
_m[0x843A] = (1,) # GL_BINORMAL_ARRAY_EXT
_m[0x8443] = (1,) # GL_BINORMAL_ARRAY_POINTER_EXT
_m[0x8441] = (1,) # GL_BINORMAL_ARRAY_STRIDE_EXT
_m[0x8440] = (1,) # GL_BINORMAL_ARRAY_TYPE_EXT
_m[0x0BE2] = (1,) # GL_BLEND
_m[0x9285] = (1,) # GL_BLEND_ADVANCED_COHERENT_KHR
_m[0x9285] = (1,) # GL_BLEND_ADVANCED_COHERENT_NV
_m[0x8005] = (4,) # GL_BLEND_COLOR
_m[0x8005] = (4,) # GL_BLEND_COLOR_EXT
_m[0x0BE0] = (1,) # GL_BLEND_DST
_m[0x80CA] = (1,) # GL_BLEND_DST_ALPHA
_m[0x80CA] = (1,) # GL_BLEND_DST_ALPHA_EXT
_m[0x80C8] = (1,) # GL_BLEND_DST_RGB
_m[0x80C8] = (1,) # GL_BLEND_DST_RGB_EXT
_m[0x8009] = (1,) # GL_BLEND_EQUATION
_m[0x883D] = (1,) # GL_BLEND_EQUATION_ALPHA
_m[0x883D] = (1,) # GL_BLEND_EQUATION_ALPHA_EXT
_m[0x8009] = (1,) # GL_BLEND_EQUATION_EXT
_m[0x8009] = (1,) # GL_BLEND_EQUATION_RGB
_m[0x9281] = (3,) # GL_BLEND_OVERLAP_NV
_m[0x9280] = (1,) # GL_BLEND_PREMULTIPLIED_SRC_NV
_m[0x0BE1] = (1,) # GL_BLEND_SRC
_m[0x80CB] = (1,) # GL_BLEND_SRC_ALPHA
_m[0x80CB] = (1,) # GL_BLEND_SRC_ALPHA_EXT
_m[0x80C9] = (1,) # GL_BLEND_SRC_RGB
_m[0x80C9] = (1,) # GL_BLEND_SRC_RGB_EXT
_m[0x92FD] = (1,) # GL_BLOCK_INDEX
_m[0x0D1B] = (1,) # GL_BLUE_BIAS
_m[0x0D54] = (1,) # GL_BLUE_BITS
_m[0x8566] = (1,) # GL_BLUE_MAX_CLAMP_INGR
_m[0x8562] = (1,) # GL_BLUE_MIN_CLAMP_INGR
_m[0x0D1A] = (1,) # GL_BLUE_SCALE
_m[0x88BB] = (1,) # GL_BUFFER_ACCESS
_m[0x911F] = (1,) # GL_BUFFER_ACCESS_FLAGS
_m[0x9302] = (1,) # GL_BUFFER_BINDING
_m[0x9303] = (1,) # GL_BUFFER_DATA_SIZE
_m[0x8F1D] = (1,) # GL_BUFFER_GPU_ADDRESS_NV
_m[0x821F] = (1,) # GL_BUFFER_IMMUTABLE_STORAGE
_m[0x88BC] = (1,) # GL_BUFFER_MAPPED
_m[0x9120] = (1,) # GL_BUFFER_MAP_LENGTH
_m[0x9121] = (1,) # GL_BUFFER_MAP_OFFSET
_m[0x88BD] = (1,) # GL_BUFFER_MAP_POINTER
_m[0x8764] = (1,) # GL_BUFFER_SIZE
_m[0x8220] = (1,) # GL_BUFFER_STORAGE_FLAGS
_m[0x8765] = (1,) # GL_BUFFER_USAGE
_m[0x877C] = (1,) # GL_BUMP_TARGET_ATI
_m[0x8183] = (1,) # GL_CALLIGRAPHIC_FRAGMENT_SGIX
_m[0x891B] = (1,) # GL_CLAMP_FRAGMENT_COLOR
_m[0x891B] = (1,) # GL_CLAMP_FRAGMENT_COLOR_ARB
_m[0x891C] = (1,) # GL_CLAMP_READ_COLOR
_m[0x891C] = (1,) # GL_CLAMP_READ_COLOR_ARB
_m[0x891A] = (1,) # GL_CLAMP_VERTEX_COLOR
_m[0x891A] = (1,) # GL_CLAMP_VERTEX_COLOR_ARB
_m[0x82B4] = (1,) # GL_CLEAR_BUFFER
_m[0x84E1] = (1,) # GL_CLIENT_ACTIVE_TEXTURE
_m[0x84E1] = (1,) # GL_CLIENT_ACTIVE_TEXTURE_ARB
_m[0x0BB1] = (1,) # GL_CLIENT_ATTRIB_STACK_DEPTH
_m[0x935D] = (2,) # GL_CLIP_DEPTH_MODE
_m[0x3000] = (1,) # GL_CLIP_DISTANCE0
_m[0x3001] = (1,) # GL_CLIP_DISTANCE1
_m[0x3002] = (1,) # GL_CLIP_DISTANCE2
_m[0x3003] = (1,) # GL_CLIP_DISTANCE3
_m[0x3004] = (1,) # GL_CLIP_DISTANCE4
_m[0x3005] = (1,) # GL_CLIP_DISTANCE5
_m[0x3006] = (1,) # GL_CLIP_DISTANCE6
_m[0x3007] = (1,) # GL_CLIP_DISTANCE7
_m[0x935C] = (2,) # GL_CLIP_ORIGIN
_m[0x3000] = (1,) # GL_CLIP_PLANE0
_m[0x3001] = (1,) # GL_CLIP_PLANE1
_m[0x3002] = (1,) # GL_CLIP_PLANE2
_m[0x3003] = (1,) # GL_CLIP_PLANE3
_m[0x3004] = (1,) # GL_CLIP_PLANE4
_m[0x3005] = (1,) # GL_CLIP_PLANE5
_m[0x80F0] = (1,) # GL_CLIP_VOLUME_CLIPPING_HINT_EXT
_m[0x8975] = (1,) # GL_COLOR_ALPHA_PAIRING_ATI
_m[0x8076] = (1,) # GL_COLOR_ARRAY
_m[0x8898] = (1,) # GL_COLOR_ARRAY_BUFFER_BINDING
_m[0x8898] = (1,) # GL_COLOR_ARRAY_BUFFER_BINDING_ARB
_m[0x8084] = (1,) # GL_COLOR_ARRAY_COUNT_EXT
_m[0x8076] = (1,) # GL_COLOR_ARRAY_EXT
_m[0x8F2D] = (1,) # GL_COLOR_ARRAY_LENGTH_NV
_m[0x83F7] = (1,) # GL_COLOR_ARRAY_PARALLEL_POINTERS_INTEL
_m[0x8090] = (1,) # GL_COLOR_ARRAY_POINTER
_m[0x8081] = (1,) # GL_COLOR_ARRAY_SIZE
_m[0x8081] = (1,) # GL_COLOR_ARRAY_SIZE_EXT
_m[0x8083] = (1,) # GL_COLOR_ARRAY_STRIDE
_m[0x8083] = (1,) # GL_COLOR_ARRAY_STRIDE_EXT
_m[0x8082] = (1,) # GL_COLOR_ARRAY_TYPE
_m[0x8082] = (1,) # GL_COLOR_ARRAY_TYPE_EXT
_m[0x8835] = (4,) # GL_COLOR_CLEAR_UNCLAMPED_VALUE_ATI
_m[0x0C22] = (4,) # GL_COLOR_CLEAR_VALUE
_m[0x8283] = (1,) # GL_COLOR_COMPONENTS
_m[0x8296] = (1,) # GL_COLOR_ENCODING
_m[0x8A0F] = (1,) # GL_COLOR_FLOAT_APPLE
_m[0x1603] = (3,) # GL_COLOR_INDEXES
_m[0x0BF2] = (1,) # GL_COLOR_LOGIC_OP
_m[0x0B57] = (1,) # GL_COLOR_MATERIAL
_m[0x0B55] = (1,) # GL_COLOR_MATERIAL_FACE
_m[0x0B56] = (1,) # GL_COLOR_MATERIAL_PARAMETER
_m[0x80B1] = (4,4) # GL_COLOR_MATRIX
_m[0x80B1] = (4,4) # GL_COLOR_MATRIX_SGI
_m[0x80B2] = (1,) # GL_COLOR_MATRIX_STACK_DEPTH
_m[0x80B2] = (1,) # GL_COLOR_MATRIX_STACK_DEPTH_SGI
_m[0x8286] = (1,) # GL_COLOR_RENDERABLE
_m[0x8E20] = (1,) # GL_COLOR_SAMPLES_NV
_m[0x8458] = (1,) # GL_COLOR_SUM
_m[0x8458] = (1,) # GL_COLOR_SUM_ARB
_m[0x854F] = (1,) # GL_COLOR_SUM_CLAMP_NV
_m[0x8458] = (1,) # GL_COLOR_SUM_EXT
_m[0x80D0] = (1,) # GL_COLOR_TABLE
_m[0x80DD] = (1,) # GL_COLOR_TABLE_ALPHA_SIZE
_m[0x80DD] = (1,) # GL_COLOR_TABLE_ALPHA_SIZE_SGI
_m[0x80D7] = (4,) # GL_COLOR_TABLE_BIAS
_m[0x80D7] = (4,) # GL_COLOR_TABLE_BIAS_SGI
_m[0x80DC] = (1,) # GL_COLOR_TABLE_BLUE_SIZE
_m[0x80DC] = (1,) # GL_COLOR_TABLE_BLUE_SIZE_SGI
_m[0x80D8] = (1,) # GL_COLOR_TABLE_FORMAT
_m[0x80D8] = (1,) # GL_COLOR_TABLE_FORMAT_SGI
_m[0x80DB] = (1,) # GL_COLOR_TABLE_GREEN_SIZE
_m[0x80DB] = (1,) # GL_COLOR_TABLE_GREEN_SIZE_SGI
_m[0x80DF] = (1,) # GL_COLOR_TABLE_INTENSITY_SIZE
_m[0x80DF] = (1,) # GL_COLOR_TABLE_INTENSITY_SIZE_SGI
_m[0x80DE] = (1,) # GL_COLOR_TABLE_LUMINANCE_SIZE
_m[0x80DE] = (1,) # GL_COLOR_TABLE_LUMINANCE_SIZE_SGI
_m[0x80DA] = (1,) # GL_COLOR_TABLE_RED_SIZE
_m[0x80DA] = (1,) # GL_COLOR_TABLE_RED_SIZE_SGI
_m[0x80D6] = (4,) # GL_COLOR_TABLE_SCALE
_m[0x80D6] = (4,) # GL_COLOR_TABLE_SCALE_SGI
_m[0x80D0] = (1,) # GL_COLOR_TABLE_SGI
_m[0x80D9] = (1,) # GL_COLOR_TABLE_WIDTH
_m[0x80D9] = (1,) # GL_COLOR_TABLE_WIDTH_SGI
_m[0x0C23] = (4,) # GL_COLOR_WRITEMASK
_m[0x8545] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/register_combiners.txt # GL_COMBINER_AB_DOT_PRODUCT_NV
_m[0x854A] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/register_combiners.txt # GL_COMBINER_AB_OUTPUT_NV
_m[0x8549] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/register_combiners.txt # GL_COMBINER_BIAS_NV
_m[0x8546] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/register_combiners.txt # GL_COMBINER_CD_DOT_PRODUCT_NV
_m[0x854B] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/register_combiners.txt # GL_COMBINER_CD_OUTPUT_NV
_m[0x8544] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/register_combiners.txt # GL_COMBINER_COMPONENT_USAGE_NV
_m[0x8542] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/register_combiners.txt # GL_COMBINER_INPUT_NV
_m[0x8543] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/register_combiners.txt # GL_COMBINER_MAPPING_NV
_m[0x8547] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/register_combiners.txt # GL_COMBINER_MUX_SUM_NV
_m[0x8548] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/register_combiners.txt # GL_COMBINER_SCALE_NV
_m[0x854C] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/register_combiners.txt # GL_COMBINER_SUM_OUTPUT_NV
_m[0x8572] = (1,) # GL_COMBINE_ALPHA
_m[0x8571] = (1,) # GL_COMBINE_RGB
_m[0x8E4B] = (1,) # GL_COMPATIBLE_SUBROUTINES
_m[0x8B81] = (1,) # GL_COMPILE_STATUS
_m[0x86A3] = (_L(0x86A2),) # GL_COMPRESSED_TEXTURE_FORMATS
_m[0x86A3] = (_L(0x86A2),) # GL_COMPRESSED_TEXTURE_FORMATS_ARB
_m[0x90FB] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/compute_program5.txt # GL_COMPUTE_PROGRAM_NV
_m[0x91B9] = (1,) # GL_COMPUTE_SHADER
_m[0x82A0] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_COMPUTE_TEXTURE
_m[0x8267] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/compute_shader.txt # GL_COMPUTE_WORK_GROUP_SIZE
_m[0x1207] = (1,) # GL_CONSTANT_ATTENUATION
_m[0x852A] = (4,) # GL_CONSTANT_COLOR0_NV
_m[0x852B] = (4,) # GL_CONSTANT_COLOR1_NV
_m[0x86E5] = (3,) # GL_CONST_EYE_NV
_m[0x821E] = (1,) # GL_CONTEXT_FLAGS
_m[0x00000002] = (1,) # GL_CONTEXT_FLAG_DEBUG_BIT
_m[0x00000004] = (1,) # GL_CONTEXT_FLAG_ROBUST_ACCESS_BIT_ARB
_m[0x9126] = (1,) # GL_CONTEXT_PROFILE_MASK
_m[0x90F3] = (1,)#TODO Review http://www.opengl.org/registry/specs//KHR/robustness.txt # GL_CONTEXT_ROBUST_ACCESS
_m[0x8010] = (1,) # GL_CONVOLUTION_1D
_m[0x8010] = (1,) # GL_CONVOLUTION_1D_EXT
_m[0x8011] = (1,) # GL_CONVOLUTION_2D
_m[0x8011] = (1,) # GL_CONVOLUTION_2D_EXT
_m[0x8154] = (4,) # GL_CONVOLUTION_BORDER_COLOR
_m[0x8013] = (1,) # GL_CONVOLUTION_BORDER_MODE
_m[0x8013] = (1,) # GL_CONVOLUTION_BORDER_MODE_EXT
_m[0x8015] = (4,) # GL_CONVOLUTION_FILTER_BIAS
_m[0x8015] = (4,) # GL_CONVOLUTION_FILTER_BIAS_EXT
_m[0x8014] = (4,) # GL_CONVOLUTION_FILTER_SCALE
_m[0x8014] = (4,) # GL_CONVOLUTION_FILTER_SCALE_EXT
_m[0x8017] = (1,) # GL_CONVOLUTION_FORMAT
_m[0x8019] = (1,) # GL_CONVOLUTION_HEIGHT
_m[0x8316] = (1,) # GL_CONVOLUTION_HINT_SGIX
_m[0x8018] = (1,) # GL_CONVOLUTION_WIDTH
_m[0x8862] = (1,) # GL_COORD_REPLACE
_m[0x8F36] = (1,) # GL_COPY_READ_BUFFER
_m[0x8F37] = (1,) # GL_COPY_WRITE_BUFFER
_m[0x8ED4] = (1,) # GL_COVERAGE_SAMPLES_NV
_m[0x0B44] = (1,) # GL_CULL_FACE
_m[0x0B45] = (1,) # GL_CULL_FACE_MODE
_m[0x86E0] = (4,) # GL_CULL_MODES_NV
_m[0x81AA] = (1,) # GL_CULL_VERTEX_EXT
_m[0x81AB] = (1,) # GL_CULL_VERTEX_EYE_POSITION_EXT
_m[103050] = (1,)#TODO Review http://www.opengl.org/registry/specs//IBM/cull_vertex.txt # GL_CULL_VERTEX_IBM
_m[0x81AC] = (1,) # GL_CULL_VERTEX_OBJECT_POSITION_EXT
_m[0x8626] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/vertex_program.txt # GL_CURRENT_ATTRIB_NV
_m[0x843C] = (1,) # GL_CURRENT_BINORMAL_EXT
_m[0x0B00] = (4,) # GL_CURRENT_COLOR
_m[0x8453] = (1,) # GL_CURRENT_FOG_COORD
_m[0x8453] = (1,) # GL_CURRENT_FOG_COORDINATE
_m[0x8453] = (1,) # GL_CURRENT_FOG_COORDINATE_EXT
_m[0x0B01] = (1,) # GL_CURRENT_INDEX
_m[0x8641] = (4, 4) # GL_CURRENT_MATRIX_ARB
_m[0x8845] = (1,) # GL_CURRENT_MATRIX_INDEX_ARB
_m[0x8641] = (4, 4) # GL_CURRENT_MATRIX_NV
_m[0x8640] = (1,) # GL_CURRENT_MATRIX_STACK_DEPTH_ARB
_m[0x8640] = (1,) # GL_CURRENT_MATRIX_STACK_DEPTH_NV
_m[0x0B02] = (3,) # GL_CURRENT_NORMAL
_m[0x8865] = (1,) # GL_CURRENT_OCCLUSION_QUERY_ID_NV
_m[0x8843] = (1,) # GL_CURRENT_PALETTE_MATRIX_ARB
_m[0x8B8D] = (1,) # GL_CURRENT_PROGRAM
_m[0x8865] = (1,) # GL_CURRENT_QUERY
_m[0x0B04] = (4,) # GL_CURRENT_RASTER_COLOR
_m[0x0B09] = (1,) # GL_CURRENT_RASTER_DISTANCE
_m[0x0B05] = (1,) # GL_CURRENT_RASTER_INDEX
_m[0x8406] = (1,) # GL_CURRENT_RASTER_NORMAL_SGIX
_m[0x0B07] = (4,) # GL_CURRENT_RASTER_POSITION
_m[0x0B08] = (1,) # GL_CURRENT_RASTER_POSITION_VALID
_m[0x0B06] = (4,) # GL_CURRENT_RASTER_TEXTURE_COORDS
_m[0x8459] = (4,) # GL_CURRENT_SECONDARY_COLOR
_m[0x8459] = (1,) # GL_CURRENT_SECONDARY_COLOR_EXT
_m[0x843B] = (1,) # GL_CURRENT_TANGENT_EXT
_m[0x0B03] = (4,) # GL_CURRENT_TEXTURE_COORDS
_m[0x8E28] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/present_video.txt # GL_CURRENT_TIME_NV
_m[0x8626] = (4,) # GL_CURRENT_VERTEX_ATTRIB
_m[0x850B] = (1,) # GL_CURRENT_VERTEX_WEIGHT_EXT
_m[0x86A8] = (1,) # GL_CURRENT_WEIGHT_ARB
_m[0x8244] = (1,) # GL_DEBUG_CALLBACK_FUNCTION
_m[0x8245] = (1,) # GL_DEBUG_CALLBACK_USER_PARAM
_m[0x826D] = (1,) # GL_DEBUG_GROUP_STACK_DEPTH
_m[0x9145] = (1,) # GL_DEBUG_LOGGED_MESSAGES
_m[0x9145] = (1,) # GL_DEBUG_LOGGED_MESSAGES_AMD
_m[0x9145] = (1,) # GL_DEBUG_LOGGED_MESSAGES_ARB
_m[0x8243] = (1,) # GL_DEBUG_NEXT_LOGGED_MESSAGE_LENGTH
_m[0x8243] = (1,) # GL_DEBUG_NEXT_LOGGED_MESSAGE_LENGTH_ARB
_m[0x92E0] = (1,) # GL_DEBUG_OUTPUT
_m[0x8242] = (1,) # GL_DEBUG_OUTPUT_SYNCHRONOUS
_m[0x8196] = (1,) # GL_DEFORMATIONS_MASK_SGIX
_m[0x8B80] = (1,) # GL_DELETE_STATUS
_m[0x0D1F] = (1,) # GL_DEPTH_BIAS
_m[0x0D56] = (1,) # GL_DEPTH_BITS
_m[0x8891] = (1,) # GL_DEPTH_BOUNDS_EXT
_m[0x8890] = (1,) # GL_DEPTH_BOUNDS_TEST_EXT
_m[0x8DAF] = (1,) # GL_DEPTH_BUFFER_FLOAT_MODE_NV
_m[0x864F] = (1,) # GL_DEPTH_CLAMP
_m[0x901F] = (1,) # GL_DEPTH_CLAMP_FAR_AMD
_m[0x901E] = (1,) # GL_DEPTH_CLAMP_NEAR_AMD
_m[0x864F] = (1,) # GL_DEPTH_CLAMP_NV
_m[0x0B73] = (1,) # GL_DEPTH_CLEAR_VALUE
_m[0x8284] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_DEPTH_COMPONENTS
_m[0x0B74] = (1,) # GL_DEPTH_FUNC
_m[0x0B70] = (2,) # GL_DEPTH_RANGE
_m[0x8287] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_DEPTH_RENDERABLE
_m[0x0D1E] = (1,) # GL_DEPTH_SCALE
_m[0x90EA] = (1,) # GL_DEPTH_STENCIL_TEXTURE_MODE
_m[0x0B71] = (1,) # GL_DEPTH_TEST
_m[0x884B] = (1,) # GL_DEPTH_TEXTURE_MODE
_m[0x0B72] = (1,) # GL_DEPTH_WRITEMASK
_m[0x8096] = (1,) # GL_DETAIL_TEXTURE_2D_BINDING_SGIS
_m[0x1201] = (4,) # GL_DIFFUSE
_m[0x90EF] = (1,) # GL_DISPATCH_INDIRECT_BUFFER_BINDING
_m[0x8129] = (3,) # GL_DISTANCE_ATTENUATION_SGIS
_m[0x0BD0] = (1,) # GL_DITHER
_m[0x0C32] = (1,) # GL_DOUBLEBUFFER
_m[0x0C01] = (1,) # GL_DRAW_BUFFER
_m[0x8825] = (1,) # GL_DRAW_BUFFER0
_m[0x8825] = (1,) # GL_DRAW_BUFFER0_ARB
_m[0x8825] = (1,) # GL_DRAW_BUFFER0_ATI
_m[0x8826] = (1,) # GL_DRAW_BUFFER1
_m[0x882F] = (1,) # GL_DRAW_BUFFER10
_m[0x882F] = (1,) # GL_DRAW_BUFFER10_ARB
_m[0x882F] = (1,) # GL_DRAW_BUFFER10_ATI
_m[0x8830] = (1,) # GL_DRAW_BUFFER11
_m[0x8830] = (1,) # GL_DRAW_BUFFER11_ARB
_m[0x8830] = (1,) # GL_DRAW_BUFFER11_ATI
_m[0x8831] = (1,) # GL_DRAW_BUFFER12
_m[0x8831] = (1,) # GL_DRAW_BUFFER12_ARB
_m[0x8831] = (1,) # GL_DRAW_BUFFER12_ATI
_m[0x8832] = (1,) # GL_DRAW_BUFFER13
_m[0x8832] = (1,) # GL_DRAW_BUFFER13_ARB
_m[0x8832] = (1,) # GL_DRAW_BUFFER13_ATI
_m[0x8833] = (1,) # GL_DRAW_BUFFER14
_m[0x8833] = (1,) # GL_DRAW_BUFFER14_ARB
_m[0x8833] = (1,) # GL_DRAW_BUFFER14_ATI
_m[0x8834] = (1,) # GL_DRAW_BUFFER15
_m[0x8834] = (1,) # GL_DRAW_BUFFER15_ARB
_m[0x8834] = (1,) # GL_DRAW_BUFFER15_ATI
_m[0x8826] = (1,) # GL_DRAW_BUFFER1_ARB
_m[0x8826] = (1,) # GL_DRAW_BUFFER1_ATI
_m[0x8827] = (1,) # GL_DRAW_BUFFER2
_m[0x8827] = (1,) # GL_DRAW_BUFFER2_ARB
_m[0x8827] = (1,) # GL_DRAW_BUFFER2_ATI
_m[0x8828] = (1,) # GL_DRAW_BUFFER3
_m[0x8828] = (1,) # GL_DRAW_BUFFER3_ARB
_m[0x8828] = (1,) # GL_DRAW_BUFFER3_ATI
_m[0x8829] = (1,) # GL_DRAW_BUFFER4
_m[0x8829] = (1,) # GL_DRAW_BUFFER4_ARB
_m[0x8829] = (1,) # GL_DRAW_BUFFER4_ATI
_m[0x882A] = (1,) # GL_DRAW_BUFFER5
_m[0x882A] = (1,) # GL_DRAW_BUFFER5_ARB
_m[0x882A] = (1,) # GL_DRAW_BUFFER5_ATI
_m[0x882B] = (1,) # GL_DRAW_BUFFER6
_m[0x882B] = (1,) # GL_DRAW_BUFFER6_ARB
_m[0x882B] = (1,) # GL_DRAW_BUFFER6_ATI
_m[0x882C] = (1,) # GL_DRAW_BUFFER7
_m[0x882C] = (1,) # GL_DRAW_BUFFER7_ARB
_m[0x882C] = (1,) # GL_DRAW_BUFFER7_ATI
_m[0x882D] = (1,) # GL_DRAW_BUFFER8
_m[0x882D] = (1,) # GL_DRAW_BUFFER8_ARB
_m[0x882D] = (1,) # GL_DRAW_BUFFER8_ATI
_m[0x882E] = (1,) # GL_DRAW_BUFFER9
_m[0x882E] = (1,) # GL_DRAW_BUFFER9_ARB
_m[0x882E] = (1,) # GL_DRAW_BUFFER9_ATI
_m[0x0C01] = (1,) # GL_DRAW_BUFFER_EXT
_m[0x8CA9] = (1,) # GL_DRAW_FRAMEBUFFER
_m[0x8CA6] = (1,) # GL_DRAW_FRAMEBUFFER_BINDING
_m[0x8F43] = (1,) # GL_DRAW_INDIRECT_BUFFER_BINDING
_m[0x8716] = (1,) # GL_DS_BIAS_NV
_m[0x8710] = (1,) # GL_DS_SCALE_NV
_m[0x8717] = (1,) # GL_DT_BIAS_NV
_m[0x8711] = (1,) # GL_DT_SCALE_NV
_m[0x0B43] = (1,) # GL_EDGE_FLAG
_m[0x8079] = (1,) # GL_EDGE_FLAG_ARRAY
_m[0x889B] = (1,) # GL_EDGE_FLAG_ARRAY_BUFFER_BINDING
_m[0x889B] = (1,) # GL_EDGE_FLAG_ARRAY_BUFFER_BINDING_ARB
_m[0x808D] = (1,) # GL_EDGE_FLAG_ARRAY_COUNT_EXT
_m[0x8079] = (1,) # GL_EDGE_FLAG_ARRAY_EXT
_m[0x8F30] = (1,) # GL_EDGE_FLAG_ARRAY_LENGTH_NV
_m[0x8093] = (1,) # GL_EDGE_FLAG_ARRAY_POINTER
_m[0x808C] = (1,) # GL_EDGE_FLAG_ARRAY_STRIDE
_m[0x808C] = (1,) # GL_EDGE_FLAG_ARRAY_STRIDE_EXT
_m[0x8895] = (1,) # GL_ELEMENT_ARRAY_BUFFER_BINDING
_m[0x8895] = (1,) # GL_ELEMENT_ARRAY_BUFFER_BINDING_ARB
_m[0x8F33] = (1,) # GL_ELEMENT_ARRAY_LENGTH_NV
_m[0x8A0E] = (1,)#TODO Review http://www.opengl.org/registry/specs//APPLE/element_array.txt # GL_ELEMENT_ARRAY_POINTER_APPLE
_m[0x8A0D] = (1,) # GL_ELEMENT_ARRAY_TYPE_APPLE
_m[0x8769] = (1,) # GL_ELEMENT_ARRAY_TYPE_ATI
_m[0x1600] = (4,) # GL_EMISSION
_m[0x86C5] = (1,) # GL_EVAL_FRACTIONAL_TESSELLATION_NV
_m[0x86C6] = (1,) # GL_EVAL_VERTEX_ATTRIB0_NV
_m[0x86D0] = (1,) # GL_EVAL_VERTEX_ATTRIB10_NV
_m[0x86D1] = (1,) # GL_EVAL_VERTEX_ATTRIB11_NV
_m[0x86D2] = (1,) # GL_EVAL_VERTEX_ATTRIB12_NV
_m[0x86D3] = (1,) # GL_EVAL_VERTEX_ATTRIB13_NV
_m[0x86D4] = (1,) # GL_EVAL_VERTEX_ATTRIB14_NV
_m[0x86D5] = (1,) # GL_EVAL_VERTEX_ATTRIB15_NV
_m[0x86C7] = (1,) # GL_EVAL_VERTEX_ATTRIB1_NV
_m[0x86C8] = (1,) # GL_EVAL_VERTEX_ATTRIB2_NV
_m[0x86C9] = (1,) # GL_EVAL_VERTEX_ATTRIB3_NV
_m[0x86CA] = (1,) # GL_EVAL_VERTEX_ATTRIB4_NV
_m[0x86CB] = (1,) # GL_EVAL_VERTEX_ATTRIB5_NV
_m[0x86CC] = (1,) # GL_EVAL_VERTEX_ATTRIB6_NV
_m[0x86CD] = (1,) # GL_EVAL_VERTEX_ATTRIB7_NV
_m[0x86CE] = (1,) # GL_EVAL_VERTEX_ATTRIB8_NV
_m[0x86CF] = (1,) # GL_EVAL_VERTEX_ATTRIB9_NV
_m[0x1F03] = (1,) # GL_EXTENSIONS
_m[0x81F6] = (7,) # GL_EYE_LINE_SGIS
_m[0x2502] = (4,) # GL_EYE_PLANE
_m[0x81F4] = (4,) # GL_EYE_POINT_SGIS
_m[0x0DF0] = (1,) # GL_FEEDBACK_BUFFER_POINTER
_m[0x0DF1] = (1,) # GL_FEEDBACK_BUFFER_SIZE
_m[0x0DF2] = (1,) # GL_FEEDBACK_BUFFER_TYPE
_m[0x84F4] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/fence.txt # GL_FENCE_CONDITION_NV
_m[0x84F3] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/fence.txt # GL_FENCE_STATUS_NV
_m[0x829A] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_FILTER
_m[0x888D] = (4,) # GL_FLOAT_CLEAR_COLOR_VALUE_NV
_m[0x888E] = (1,) # GL_FLOAT_RGBA_MODE_NV
_m[0x0B60] = (1,) # GL_FOG
_m[0x0B66] = (4,) # GL_FOG_COLOR
_m[0x889D] = (1,) # GL_FOG_COORDINATE_ARRAY_BUFFER_BINDING_ARB
_m[0x8456] = (1,)#TODO Review http://www.opengl.org/registry/specs//EXT/fog_coord.txt # GL_FOG_COORDINATE_ARRAY_POINTER_EXT
_m[0x8455] = (1,) # GL_FOG_COORDINATE_ARRAY_STRIDE_EXT
_m[0x8454] = (1,) # GL_FOG_COORDINATE_ARRAY_TYPE_EXT
_m[0x8457] = (1,) # GL_FOG_COORD_ARRAY
_m[0x889D] = (1,) # GL_FOG_COORD_ARRAY_BUFFER_BINDING
_m[0x8F32] = (1,) # GL_FOG_COORD_ARRAY_LENGTH_NV
_m[0x8455] = (1,) # GL_FOG_COORD_ARRAY_STRIDE
_m[0x8454] = (1,) # GL_FOG_COORD_ARRAY_TYPE
_m[0x8450] = (1,) # GL_FOG_COORD_SRC
_m[0x0B62] = (1,) # GL_FOG_DENSITY
_m[0x855A] = (1,) # GL_FOG_DISTANCE_MODE_NV
_m[0x0B64] = (1,) # GL_FOG_END
_m[0x812B] = (1,) # GL_FOG_FUNC_POINTS_SGIS
_m[0x0C54] = (1,) # GL_FOG_HINT
_m[0x0B61] = (1,) # GL_FOG_INDEX
_m[0x0B65] = (1,) # GL_FOG_MODE
_m[0x8198] = (1,) # GL_FOG_OFFSET_SGIX
_m[0x8199] = (4,) # GL_FOG_OFFSET_VALUE_SGIX
_m[0x0B63] = (1,) # GL_FOG_START
_m[0x8402] = (1,) # GL_FRAGMENT_COLOR_MATERIAL_FACE_SGIX
_m[0x8403] = (1,) # GL_FRAGMENT_COLOR_MATERIAL_PARAMETER_SGIX
_m[0x8401] = (1,) # GL_FRAGMENT_COLOR_MATERIAL_SGIX
_m[0x8E5D] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/gpu_shader5.txt # GL_FRAGMENT_INTERPOLATION_OFFSET_BITS
_m[0x840C] = (1,) # GL_FRAGMENT_LIGHT0_SGIX
_m[0x8400] = (1,) # GL_FRAGMENT_LIGHTING_SGIX
_m[0x840A] = (4,) # GL_FRAGMENT_LIGHT_MODEL_AMBIENT_SGIX
_m[0x8408] = (1,) # GL_FRAGMENT_LIGHT_MODEL_LOCAL_VIEWER_SGIX
_m[0x840B] = (1,) # GL_FRAGMENT_LIGHT_MODEL_NORMAL_INTERPOLATION_SGIX
_m[0x8409] = (1,) # GL_FRAGMENT_LIGHT_MODEL_TWO_SIDE_SGIX
_m[0x8804] = (1,) # GL_FRAGMENT_PROGRAM_ARB
_m[0x8873] = (1,) # GL_FRAGMENT_PROGRAM_BINDING_NV
_m[0x8E5D] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/gpu_program5.txt # GL_FRAGMENT_PROGRAM_INTERPOLATION_OFFSET_BITS_NV
_m[0x8870] = (1,) # GL_FRAGMENT_PROGRAM_NV
_m[0x8DA4] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/parameter_buffer_object.txt # GL_FRAGMENT_PROGRAM_PARAMETER_BUFFER_NV
_m[0x8B30] = (1,) # GL_FRAGMENT_SHADER
_m[0x8920] = (1,) # GL_FRAGMENT_SHADER_ATI
_m[0x8B8B] = (1,) # GL_FRAGMENT_SHADER_DERIVATIVE_HINT
_m[0x8B8B] = (1,) # GL_FRAGMENT_SHADER_DERIVATIVE_HINT_ARB
_m[0x829F] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_FRAGMENT_TEXTURE
_m[0x8215] = (1,) # GL_FRAMEBUFFER_ATTACHMENT_ALPHA_SIZE
_m[0x8214] = (1,) # GL_FRAMEBUFFER_ATTACHMENT_BLUE_SIZE
_m[0x8210] = (1,) # GL_FRAMEBUFFER_ATTACHMENT_COLOR_ENCODING
_m[0x8211] = (1,) # GL_FRAMEBUFFER_ATTACHMENT_COMPONENT_TYPE
_m[0x8216] = (1,) # GL_FRAMEBUFFER_ATTACHMENT_DEPTH_SIZE
_m[0x8213] = (1,) # GL_FRAMEBUFFER_ATTACHMENT_GREEN_SIZE
_m[0x8DA7] = (1,) # GL_FRAMEBUFFER_ATTACHMENT_LAYERED
_m[0x8CD1] = (1,) # GL_FRAMEBUFFER_ATTACHMENT_OBJECT_NAME
_m[0x8CD0] = (1,) # GL_FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE
_m[0x8212] = (1,) # GL_FRAMEBUFFER_ATTACHMENT_RED_SIZE
_m[0x8217] = (1,) # GL_FRAMEBUFFER_ATTACHMENT_STENCIL_SIZE
_m[0x8CD3] = (1,) # GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE
_m[0x8CD4] = (1,) # GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LAYER
_m[0x8CD2] = (1,) # GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL
_m[0x8CA6] = (1,) # GL_FRAMEBUFFER_BINDING_EXT
_m[0x828B] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_FRAMEBUFFER_BLEND
_m[0x9314] = (1,) # GL_FRAMEBUFFER_DEFAULT_FIXED_SAMPLE_LOCATIONS
_m[0x9311] = (1,) # GL_FRAMEBUFFER_DEFAULT_HEIGHT
_m[0x9312] = (1,) # GL_FRAMEBUFFER_DEFAULT_LAYERS
_m[0x9313] = (1,) # GL_FRAMEBUFFER_DEFAULT_SAMPLES
_m[0x9310] = (1,) # GL_FRAMEBUFFER_DEFAULT_WIDTH
_m[0x8289] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_FRAMEBUFFER_RENDERABLE
_m[0x828A] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_FRAMEBUFFER_RENDERABLE_LAYERED
_m[0x8DB9] = (1,) # GL_FRAMEBUFFER_SRGB
_m[0x8DBA] = (1,) # GL_FRAMEBUFFER_SRGB_CAPABLE_EXT
_m[0x8DB9] = (1,) # GL_FRAMEBUFFER_SRGB_EXT
_m[0x818C] = (1,) # GL_FRAMEZOOM_FACTOR_SGIX
_m[0x818B] = (1,) # GL_FRAMEZOOM_SGIX
_m[0x0B46] = (1,) # GL_FRONT_FACE
_m[0x8191] = (1,) # GL_GENERATE_MIPMAP
_m[0x8192] = (1,) # GL_GENERATE_MIPMAP_HINT
_m[0x8192] = (1,) # GL_GENERATE_MIPMAP_HINT_SGIS
_m[0x8DDB] = (1,) # GL_GEOMETRY_INPUT_TYPE_ARB
_m[0x8DDB] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/geometry_program4.txt # GL_GEOMETRY_INPUT_TYPE_EXT
_m[0x8DDC] = (1,) # GL_GEOMETRY_OUTPUT_TYPE_ARB
_m[0x8DDC] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/geometry_program4.txt # GL_GEOMETRY_OUTPUT_TYPE_EXT
_m[0x8C26] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/geometry_program4.txt # GL_GEOMETRY_PROGRAM_NV
_m[0x8DA3] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/parameter_buffer_object.txt # GL_GEOMETRY_PROGRAM_PARAMETER_BUFFER_NV
_m[0x8DD9] = (1,) # GL_GEOMETRY_SHADER
_m[0x887F] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/gpu_shader5.txt # GL_GEOMETRY_SHADER_INVOCATIONS
_m[0x829E] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_GEOMETRY_TEXTURE
_m[0x8DDA] = (1,) # GL_GEOMETRY_VERTICES_OUT_ARB
_m[0x8DDA] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/geometry_program4.txt # GL_GEOMETRY_VERTICES_OUT_EXT
_m[0x8291] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_GET_TEXTURE_IMAGE_FORMAT
_m[0x8292] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_GET_TEXTURE_IMAGE_TYPE
_m[0x81DA] = (1,) # GL_GLOBAL_ALPHA_FACTOR_SUN
_m[0x9049] = (1,) # GL_GPU_MEMORY_INFO_CURRENT_AVAILABLE_VIDMEM_NVX
_m[0x9047] = (1,) # GL_GPU_MEMORY_INFO_DEDICATED_VIDMEM_NVX
_m[0x904B] = (1,) # GL_GPU_MEMORY_INFO_EVICTED_MEMORY_NVX
_m[0x904A] = (1,) # GL_GPU_MEMORY_INFO_EVICTION_COUNT_NVX
_m[0x9048] = (1,) # GL_GPU_MEMORY_INFO_TOTAL_AVAILABLE_MEMORY_NVX
_m[0x0D19] = (1,) # GL_GREEN_BIAS
_m[0x0D53] = (1,) # GL_GREEN_BITS
_m[0x8565] = (1,) # GL_GREEN_MAX_CLAMP_INGR
_m[0x8561] = (1,) # GL_GREEN_MIN_CLAMP_INGR
_m[0x0D18] = (1,) # GL_GREEN_SCALE
_m[0x8024] = (1,) # GL_HISTOGRAM
_m[0x802B] = (1,) # GL_HISTOGRAM_ALPHA_SIZE
_m[0x802B] = (1,) # GL_HISTOGRAM_ALPHA_SIZE_EXT
_m[0x802A] = (1,) # GL_HISTOGRAM_BLUE_SIZE
_m[0x802A] = (1,) # GL_HISTOGRAM_BLUE_SIZE_EXT
_m[0x8024] = (1,) # GL_HISTOGRAM_EXT
_m[0x8027] = (1,) # GL_HISTOGRAM_FORMAT
_m[0x8027] = (1,) # GL_HISTOGRAM_FORMAT_EXT
_m[0x8029] = (1,) # GL_HISTOGRAM_GREEN_SIZE
_m[0x8029] = (1,) # GL_HISTOGRAM_GREEN_SIZE_EXT
_m[0x802C] = (1,) # GL_HISTOGRAM_LUMINANCE_SIZE
_m[0x802C] = (1,) # GL_HISTOGRAM_LUMINANCE_SIZE_EXT
_m[0x8028] = (1,) # GL_HISTOGRAM_RED_SIZE
_m[0x8028] = (1,) # GL_HISTOGRAM_RED_SIZE_EXT
_m[0x802D] = (1,) # GL_HISTOGRAM_SINK
_m[0x802D] = (1,) # GL_HISTOGRAM_SINK_EXT
_m[0x8026] = (1,) # GL_HISTOGRAM_WIDTH
_m[0x8026] = (1,) # GL_HISTOGRAM_WIDTH_EXT
_m[0x8714] = (1,) # GL_HI_BIAS_NV
_m[0x870E] = (1,) # GL_HI_SCALE_NV
_m[0x82A8] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_IMAGE_COMPATIBILITY_CLASS
_m[0x90C7] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_IMAGE_FORMAT_COMPATIBILITY_TYPE
_m[0x82A9] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_IMAGE_PIXEL_FORMAT
_m[0x82AA] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_IMAGE_PIXEL_TYPE
_m[0x82A7] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_IMAGE_TEXEL_SIZE
_m[0x8B9B] = (1,) # GL_IMPLEMENTATION_COLOR_READ_FORMAT
_m[0x8B9A] = (1,) # GL_IMPLEMENTATION_COLOR_READ_TYPE
_m[0x8077] = (1,) # GL_INDEX_ARRAY
_m[0x8899] = (1,) # GL_INDEX_ARRAY_BUFFER_BINDING
_m[0x8899] = (1,) # GL_INDEX_ARRAY_BUFFER_BINDING_ARB
_m[0x8087] = (1,) # GL_INDEX_ARRAY_COUNT_EXT
_m[0x8077] = (1,) # GL_INDEX_ARRAY_EXT
_m[0x8F2E] = (1,) # GL_INDEX_ARRAY_LENGTH_NV
_m[0x8091] = (1,) # GL_INDEX_ARRAY_POINTER
_m[0x8086] = (1,) # GL_INDEX_ARRAY_STRIDE
_m[0x8086] = (1,) # GL_INDEX_ARRAY_STRIDE_EXT
_m[0x8085] = (1,) # GL_INDEX_ARRAY_TYPE
_m[0x8085] = (1,) # GL_INDEX_ARRAY_TYPE_EXT
_m[0x0D51] = (1,) # GL_INDEX_BITS
_m[0x0C20] = (1,) # GL_INDEX_CLEAR_VALUE
_m[0x0BF1] = (1,) # GL_INDEX_LOGIC_OP
_m[0x0C30] = (1,) # GL_INDEX_MODE
_m[0x0D13] = (1,) # GL_INDEX_OFFSET
_m[0x0D12] = (1,) # GL_INDEX_SHIFT
_m[0x0C21] = (1,) # GL_INDEX_WRITEMASK
_m[0x8B84] = (1,) # GL_INFO_LOG_LENGTH
_m[0x8181] = (1,) # GL_INSTRUMENT_MEASUREMENTS_SGIX
_m[0x8980] = (1,) # GL_INTERLACE_OML
_m[0x8568] = (1,) # GL_INTERLACE_READ_INGR
_m[0x8981] = (1,) # GL_INTERLACE_READ_OML
_m[0x8094] = (1,) # GL_INTERLACE_SGIX
_m[0x8274] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_INTERNALFORMAT_ALPHA_SIZE
_m[0x827B] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_INTERNALFORMAT_ALPHA_TYPE
_m[0x8273] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_INTERNALFORMAT_BLUE_SIZE
_m[0x827A] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_INTERNALFORMAT_BLUE_TYPE
_m[0x8275] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_INTERNALFORMAT_DEPTH_SIZE
_m[0x827C] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_INTERNALFORMAT_DEPTH_TYPE
_m[0x8272] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_INTERNALFORMAT_GREEN_SIZE
_m[0x8279] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_INTERNALFORMAT_GREEN_TYPE
_m[0x8270] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_INTERNALFORMAT_PREFERRED
_m[0x8271] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_INTERNALFORMAT_RED_SIZE
_m[0x8278] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_INTERNALFORMAT_RED_TYPE
_m[0x8277] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_INTERNALFORMAT_SHARED_SIZE
_m[0x8276] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_INTERNALFORMAT_STENCIL_SIZE
_m[0x827D] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_INTERNALFORMAT_STENCIL_TYPE
_m[0x826F] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_INTERNALFORMAT_SUPPORTED
_m[0x817F] = (1,) # GL_IR_INSTRUMENT1_SGIX
_m[0x92E7] = (1,) # GL_IS_PER_PATCH
_m[0x9300] = (1,) # GL_IS_ROW_MAJOR
_m[0x825E] = (1,) # GL_LAYER_PROVOKING_VERTEX
_m[0x4000] = (1,) # GL_LIGHT0
_m[0x4001] = (1,) # GL_LIGHT1
_m[0x4002] = (1,) # GL_LIGHT2
_m[0x4003] = (1,) # GL_LIGHT3
_m[0x4004] = (1,) # GL_LIGHT4
_m[0x4005] = (1,) # GL_LIGHT5
_m[0x4006] = (1,) # GL_LIGHT6
_m[0x4007] = (1,) # GL_LIGHT7
_m[0x0B50] = (1,) # GL_LIGHTING
_m[0x8407] = (1,) # GL_LIGHT_ENV_MODE_SGIX
_m[0x0B53] = (4,) # GL_LIGHT_MODEL_AMBIENT
_m[0x81F8] = (1,) # GL_LIGHT_MODEL_COLOR_CONTROL
_m[0x81F8] = (1,) # GL_LIGHT_MODEL_COLOR_CONTROL_EXT
_m[0x0B51] = (1,) # GL_LIGHT_MODEL_LOCAL_VIEWER
_m[0x0B52] = (1,) # GL_LIGHT_MODEL_TWO_SIDE
_m[0x1208] = (1,) # GL_LINEAR_ATTENUATION
_m[0x0B20] = (1,) # GL_LINE_SMOOTH
_m[0x0C52] = (1,) # GL_LINE_SMOOTH_HINT
_m[0x0B24] = (1,) # GL_LINE_STIPPLE
_m[0x0B25] = (1,) # GL_LINE_STIPPLE_PATTERN
_m[0x0B26] = (1,) # GL_LINE_STIPPLE_REPEAT
_m[0x0B21] = (1,) # GL_LINE_WIDTH
_m[0x0B23] = (1,) # GL_LINE_WIDTH_GRANULARITY
_m[0x0B22] = (2,) # GL_LINE_WIDTH_RANGE
_m[0x8B82] = (1,) # GL_LINK_STATUS
_m[0x0B32] = (1,) # GL_LIST_BASE
_m[0x0B33] = (1,) # GL_LIST_INDEX
_m[0x0B30] = (1,) # GL_LIST_MODE
_m[0x930E] = (1,) # GL_LOCATION
_m[0x930F] = (1,) # GL_LOCATION_INDEX
_m[0x0BF1] = (1,) # GL_LOGIC_OP
_m[0x0BF0] = (1,) # GL_LOGIC_OP_MODE
_m[0x8252] = (1,)#TODO Review http://www.opengl.org/registry/specs//KHR/robustness.txt # GL_LOSE_CONTEXT_ON_RESET
_m[0x8252] = (1,) # GL_LOSE_CONTEXT_ON_RESET_ARB
_m[0x8715] = (1,) # GL_LO_BIAS_NV
_m[0x870F] = (1,) # GL_LO_SCALE_NV
_m[0x8718] = (1,) # GL_MAGNITUDE_BIAS_NV
_m[0x8712] = (1,) # GL_MAGNITUDE_SCALE_NV
_m[0x821B] = (1,) # GL_MAJOR_VERSION
_m[0x8294] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_MANUAL_GENERATE_MIPMAP
_m[0x0D90] = (1,) # GL_MAP1_COLOR_4
_m[0x0DD0] = (2,) # GL_MAP1_GRID_DOMAIN
_m[0x0DD1] = (1,) # GL_MAP1_GRID_SEGMENTS
_m[0x0D91] = (1,) # GL_MAP1_INDEX
_m[0x0D92] = (1,) # GL_MAP1_NORMAL
_m[0x0D93] = (1,) # GL_MAP1_TEXTURE_COORD_1
_m[0x0D94] = (1,) # GL_MAP1_TEXTURE_COORD_2
_m[0x0D95] = (1,) # GL_MAP1_TEXTURE_COORD_3
_m[0x0D96] = (1,) # GL_MAP1_TEXTURE_COORD_4
_m[0x0D97] = (1,) # GL_MAP1_VERTEX_3
_m[0x0D98] = (1,) # GL_MAP1_VERTEX_4
_m[0x8660] = (4,) # GL_MAP1_VERTEX_ATTRIB0_4_NV
_m[0x866A] = (4,) # GL_MAP1_VERTEX_ATTRIB10_4_NV
_m[0x866B] = (4,) # GL_MAP1_VERTEX_ATTRIB11_4_NV
_m[0x866C] = (4,) # GL_MAP1_VERTEX_ATTRIB12_4_NV
_m[0x866D] = (4,) # GL_MAP1_VERTEX_ATTRIB13_4_NV
_m[0x866E] = (4,) # GL_MAP1_VERTEX_ATTRIB14_4_NV
_m[0x866F] = (4,) # GL_MAP1_VERTEX_ATTRIB15_4_NV
_m[0x8661] = (4,) # GL_MAP1_VERTEX_ATTRIB1_4_NV
_m[0x8662] = (4,) # GL_MAP1_VERTEX_ATTRIB2_4_NV
_m[0x8663] = (4,) # GL_MAP1_VERTEX_ATTRIB3_4_NV
_m[0x8664] = (4,) # GL_MAP1_VERTEX_ATTRIB4_4_NV
_m[0x8665] = (4,) # GL_MAP1_VERTEX_ATTRIB5_4_NV
_m[0x8666] = (4,) # GL_MAP1_VERTEX_ATTRIB6_4_NV
_m[0x8667] = (4,) # GL_MAP1_VERTEX_ATTRIB7_4_NV
_m[0x8668] = (4,) # GL_MAP1_VERTEX_ATTRIB8_4_NV
_m[0x8669] = (4,) # GL_MAP1_VERTEX_ATTRIB9_4_NV
_m[0x0DB0] = (1,) # GL_MAP2_COLOR_4
_m[0x0DD2] = (4,) # GL_MAP2_GRID_DOMAIN
_m[0x0DD3] = (2,) # GL_MAP2_GRID_SEGMENTS
_m[0x0DB1] = (1,) # GL_MAP2_INDEX
_m[0x0DB2] = (1,) # GL_MAP2_NORMAL
_m[0x0DB3] = (1,) # GL_MAP2_TEXTURE_COORD_1
_m[0x0DB4] = (1,) # GL_MAP2_TEXTURE_COORD_2
_m[0x0DB5] = (1,) # GL_MAP2_TEXTURE_COORD_3
_m[0x0DB6] = (1,) # GL_MAP2_TEXTURE_COORD_4
_m[0x0DB7] = (1,) # GL_MAP2_VERTEX_3
_m[0x0DB8] = (1,) # GL_MAP2_VERTEX_4
_m[0x8670] = (4,) # GL_MAP2_VERTEX_ATTRIB0_4_NV
_m[0x867A] = (4,) # GL_MAP2_VERTEX_ATTRIB10_4_NV
_m[0x867B] = (4,) # GL_MAP2_VERTEX_ATTRIB11_4_NV
_m[0x867C] = (4,) # GL_MAP2_VERTEX_ATTRIB12_4_NV
_m[0x867D] = (4,) # GL_MAP2_VERTEX_ATTRIB13_4_NV
_m[0x867E] = (4,) # GL_MAP2_VERTEX_ATTRIB14_4_NV
_m[0x867F] = (4,) # GL_MAP2_VERTEX_ATTRIB15_4_NV
_m[0x8671] = (4,) # GL_MAP2_VERTEX_ATTRIB1_4_NV
_m[0x8672] = (4,) # GL_MAP2_VERTEX_ATTRIB2_4_NV
_m[0x8673] = (4,) # GL_MAP2_VERTEX_ATTRIB3_4_NV
_m[0x8674] = (4,) # GL_MAP2_VERTEX_ATTRIB4_4_NV
_m[0x8675] = (4,) # GL_MAP2_VERTEX_ATTRIB5_4_NV
_m[0x8676] = (4,) # GL_MAP2_VERTEX_ATTRIB6_4_NV
_m[0x8677] = (4,) # GL_MAP2_VERTEX_ATTRIB7_4_NV
_m[0x8678] = (4,) # GL_MAP2_VERTEX_ATTRIB8_4_NV
_m[0x8679] = (4,) # GL_MAP2_VERTEX_ATTRIB9_4_NV
_m[0x86C3] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/evaluators.txt # GL_MAP_ATTRIB_U_ORDER_NV
_m[0x86C4] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/evaluators.txt # GL_MAP_ATTRIB_V_ORDER_NV
_m[0x0D10] = (1,) # GL_MAP_COLOR
_m[0x0D11] = (1,) # GL_MAP_STENCIL
_m[0x8844] = (1,) # GL_MATRIX_INDEX_ARRAY_ARB
_m[0x8849] = (1,) # GL_MATRIX_INDEX_ARRAY_POINTER_ARB
_m[0x8846] = (1,) # GL_MATRIX_INDEX_ARRAY_SIZE_ARB
_m[0x8848] = (1,) # GL_MATRIX_INDEX_ARRAY_STRIDE_ARB
_m[0x8847] = (1,) # GL_MATRIX_INDEX_ARRAY_TYPE_ARB
_m[0x0BA0] = (1,) # GL_MATRIX_MODE
_m[0x8840] = (1,) # GL_MATRIX_PALETTE_ARB
_m[0x92FF] = (1,) # GL_MATRIX_STRIDE
_m[0x8073] = (1,) # GL_MAX_3D_TEXTURE_SIZE
_m[0x8073] = (1,) # GL_MAX_3D_TEXTURE_SIZE_EXT
_m[0x8138] = (1,) # GL_MAX_4D_TEXTURE_SIZE_SGIS
_m[0x8405] = (1,) # GL_MAX_ACTIVE_LIGHTS_SGIX
_m[0x88FF] = (1,) # GL_MAX_ARRAY_TEXTURE_LAYERS
_m[0x88FF] = (1,) # GL_MAX_ARRAY_TEXTURE_LAYERS_EXT
_m[0x8360] = (1,) # GL_MAX_ASYNC_DRAW_PIXELS_SGIX
_m[0x832D] = (1,) # GL_MAX_ASYNC_HISTOGRAM_SGIX
_m[0x8361] = (1,) # GL_MAX_ASYNC_READ_PIXELS_SGIX
_m[0x835F] = (1,) # GL_MAX_ASYNC_TEX_IMAGE_SGIX
_m[0x92DC] = (1,) # GL_MAX_ATOMIC_COUNTER_BUFFER_BINDINGS
_m[0x92D8] = (1,) # GL_MAX_ATOMIC_COUNTER_BUFFER_SIZE
_m[0x0D35] = (1,) # GL_MAX_ATTRIB_STACK_DEPTH
_m[0x8DED] = (1,) # GL_MAX_BINDABLE_UNIFORM_SIZE_EXT
_m[0x0D3B] = (1,) # GL_MAX_CLIENT_ATTRIB_STACK_DEPTH
_m[0x8177] = (1,) # GL_MAX_CLIPMAP_DEPTH_SGIX
_m[0x8178] = (1,) # GL_MAX_CLIPMAP_VIRTUAL_DEPTH_SGIX
_m[0x0D32] = (1,) # GL_MAX_CLIP_DISTANCES
_m[0x0D32] = (1,) # GL_MAX_CLIP_PLANES
_m[0x8CDF] = (1,) # GL_MAX_COLOR_ATTACHMENTS
_m[0x8CDF] = (1,) # GL_MAX_COLOR_ATTACHMENTS_EXT
_m[0x80B3] = (1,) # GL_MAX_COLOR_MATRIX_STACK_DEPTH
_m[0x80B3] = (1,) # GL_MAX_COLOR_MATRIX_STACK_DEPTH_SGI
_m[0x910E] = (1,) # GL_MAX_COLOR_TEXTURE_SAMPLES
_m[0x92D7] = (1,) # GL_MAX_COMBINED_ATOMIC_COUNTERS
_m[0x92D1] = (1,) # GL_MAX_COMBINED_ATOMIC_COUNTER_BUFFERS
_m[0x82FA] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/cull_distance.txt # GL_MAX_COMBINED_CLIP_AND_CULL_DISTANCES
_m[0x8266] = (1,) # GL_MAX_COMBINED_COMPUTE_UNIFORM_COMPONENTS
_m[0x8282] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_MAX_COMBINED_DIMENSIONS
_m[0x8A33] = (1,) # GL_MAX_COMBINED_FRAGMENT_UNIFORM_COMPONENTS
_m[0x8A32] = (1,) # GL_MAX_COMBINED_GEOMETRY_UNIFORM_COMPONENTS
_m[0x90CF] = (1,) # GL_MAX_COMBINED_IMAGE_UNIFORMS
_m[0x8F39] = (1,) # GL_MAX_COMBINED_IMAGE_UNITS_AND_FRAGMENT_OUTPUTS
_m[0x8F39] = (1,) # GL_MAX_COMBINED_IMAGE_UNITS_AND_FRAGMENT_OUTPUTS_EXT
_m[0x90DC] = (1,) # GL_MAX_COMBINED_SHADER_STORAGE_BLOCKS
_m[0x8E1E] = (1,) # GL_MAX_COMBINED_TESS_CONTROL_UNIFORM_COMPONENTS
_m[0x8E1F] = (1,) # GL_MAX_COMBINED_TESS_EVALUATION_UNIFORM_COMPONENTS
_m[0x8B4D] = (1,) # GL_MAX_COMBINED_TEXTURE_IMAGE_UNITS
_m[0x8B4D] = (1,) # GL_MAX_COMBINED_TEXTURE_IMAGE_UNITS_ARB
_m[0x8A2E] = (1,) # GL_MAX_COMBINED_UNIFORM_BLOCKS
_m[0x8A31] = (1,) # GL_MAX_COMBINED_VERTEX_UNIFORM_COMPONENTS
_m[0x8265] = (1,) # GL_MAX_COMPUTE_ATOMIC_COUNTERS
_m[0x8264] = (1,) # GL_MAX_COMPUTE_ATOMIC_COUNTER_BUFFERS
_m[0x91BD] = (1,) # GL_MAX_COMPUTE_IMAGE_UNIFORMS
_m[0x90DB] = (1,) # GL_MAX_COMPUTE_SHADER_STORAGE_BLOCKS
_m[0x8262] = (1,) # GL_MAX_COMPUTE_SHARED_MEMORY_SIZE
_m[0x91BC] = (1,) # GL_MAX_COMPUTE_TEXTURE_IMAGE_UNITS
_m[0x91BB] = (1,) # GL_MAX_COMPUTE_UNIFORM_BLOCKS
_m[0x8263] = (1,) # GL_MAX_COMPUTE_UNIFORM_COMPONENTS
_m[0x9344] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/compute_variable_group_size.txt # GL_MAX_COMPUTE_VARIABLE_GROUP_INVOCATIONS_ARB
_m[0x9345] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/compute_variable_group_size.txt # GL_MAX_COMPUTE_VARIABLE_GROUP_SIZE_ARB
_m[0x91BE] = (3,) # GL_MAX_COMPUTE_WORK_GROUP_COUNT
_m[0x90EB] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/compute_shader.txt # GL_MAX_COMPUTE_WORK_GROUP_INVOCATIONS
_m[0x91BF] = (3,) # GL_MAX_COMPUTE_WORK_GROUP_SIZE
_m[0x801B] = (1,) # GL_MAX_CONVOLUTION_HEIGHT
_m[0x801A] = (1,) # GL_MAX_CONVOLUTION_WIDTH
_m[0x851C] = (1,) # GL_MAX_CUBE_MAP_TEXTURE_SIZE
_m[0x851C] = (1,) # GL_MAX_CUBE_MAP_TEXTURE_SIZE_ARB
_m[0x82F9] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/cull_distance.txt # GL_MAX_CULL_DISTANCES
_m[0x826C] = (1,) # GL_MAX_DEBUG_GROUP_STACK_DEPTH
_m[0x9144] = (1,) # GL_MAX_DEBUG_LOGGED_MESSAGES
_m[0x9144] = (1,) # GL_MAX_DEBUG_LOGGED_MESSAGES_AMD
_m[0x9144] = (1,) # GL_MAX_DEBUG_LOGGED_MESSAGES_ARB
_m[0x9143] = (1,) # GL_MAX_DEBUG_MESSAGE_LENGTH
_m[0x9143] = (1,) # GL_MAX_DEBUG_MESSAGE_LENGTH_AMD
_m[0x9143] = (1,) # GL_MAX_DEBUG_MESSAGE_LENGTH_ARB
_m[0x90D1] = (1,) # GL_MAX_DEEP_3D_TEXTURE_DEPTH_NV
_m[0x90D0] = (2,) # GL_MAX_DEEP_3D_TEXTURE_WIDTH_HEIGHT_NV
_m[0x8280] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_MAX_DEPTH
_m[0x910F] = (1,) # GL_MAX_DEPTH_TEXTURE_SAMPLES
_m[0x8824] = (1,) # GL_MAX_DRAW_BUFFERS
_m[0x8824] = (1,) # GL_MAX_DRAW_BUFFERS_ARB
_m[0x8824] = (1,) # GL_MAX_DRAW_BUFFERS_ATI
_m[0x88FC] = (1,) # GL_MAX_DUAL_SOURCE_DRAW_BUFFERS
_m[0x80E9] = (1,) # GL_MAX_ELEMENTS_INDICES
_m[0x80E8] = (1,) # GL_MAX_ELEMENTS_VERTICES
_m[0x8D6B] = (1,) # GL_MAX_ELEMENT_INDEX
_m[0x0D30] = (1,) # GL_MAX_EVAL_ORDER
_m[0x812C] = (1,) # GL_MAX_FOG_FUNC_POINTS_SGIS
_m[0x92D6] = (1,) # GL_MAX_FRAGMENT_ATOMIC_COUNTERS
_m[0x92D0] = (1,) # GL_MAX_FRAGMENT_ATOMIC_COUNTER_BUFFERS
_m[0x8DE3] = (1,) # GL_MAX_FRAGMENT_BINDABLE_UNIFORMS_EXT
_m[0x90CE] = (1,) # GL_MAX_FRAGMENT_IMAGE_UNIFORMS
_m[0x8E5C] = (1,) # GL_MAX_FRAGMENT_INTERPOLATION_OFFSET
_m[0x8E5C] = (1,) # GL_MAX_FRAGMENT_INTERPOLATION_OFFSET_NV
_m[0x8404] = (1,) # GL_MAX_FRAGMENT_LIGHTS_SGIX
_m[0x8868] = (1,) # GL_MAX_FRAGMENT_PROGRAM_LOCAL_PARAMETERS_NV
_m[0x90DA] = (1,) # GL_MAX_FRAGMENT_SHADER_STORAGE_BLOCKS
_m[0x8A2D] = (1,) # GL_MAX_FRAGMENT_UNIFORM_BLOCKS
_m[0x8B49] = (1,) # GL_MAX_FRAGMENT_UNIFORM_COMPONENTS
_m[0x8B49] = (1,) # GL_MAX_FRAGMENT_UNIFORM_COMPONENTS_ARB
_m[0x8DFD] = (1,) # GL_MAX_FRAGMENT_UNIFORM_VECTORS
_m[0x9316] = (1,) # GL_MAX_FRAMEBUFFER_HEIGHT
_m[0x9317] = (1,) # GL_MAX_FRAMEBUFFER_LAYERS
_m[0x9318] = (1,) # GL_MAX_FRAMEBUFFER_SAMPLES
_m[0x9315] = (1,) # GL_MAX_FRAMEBUFFER_WIDTH
_m[0x818D] = (1,) # GL_MAX_FRAMEZOOM_FACTOR_SGIX
_m[0x854D] = (1,) # GL_MAX_GENERAL_COMBINERS_NV
_m[0x92D5] = (1,) # GL_MAX_GEOMETRY_ATOMIC_COUNTERS
_m[0x92CF] = (1,) # GL_MAX_GEOMETRY_ATOMIC_COUNTER_BUFFERS
_m[0x8DE4] = (1,) # GL_MAX_GEOMETRY_BINDABLE_UNIFORMS_EXT
_m[0x90CD] = (1,) # GL_MAX_GEOMETRY_IMAGE_UNIFORMS
_m[0x8DE0] = (1,) # GL_MAX_GEOMETRY_OUTPUT_VERTICES
_m[0x8DE0] = (1,) # GL_MAX_GEOMETRY_OUTPUT_VERTICES_ARB
_m[0x8DE0] = (1,) # GL_MAX_GEOMETRY_OUTPUT_VERTICES_EXT
_m[0x8E5A] = (1,) # GL_MAX_GEOMETRY_PROGRAM_INVOCATIONS_NV
_m[0x8E5A] = (1,) # GL_MAX_GEOMETRY_SHADER_INVOCATIONS
_m[0x90D7] = (1,) # GL_MAX_GEOMETRY_SHADER_STORAGE_BLOCKS
_m[0x8C29] = (1,) # GL_MAX_GEOMETRY_TEXTURE_IMAGE_UNITS
_m[0x8C29] = (1,) # GL_MAX_GEOMETRY_TEXTURE_IMAGE_UNITS_ARB
_m[0x8C29] = (1,) # GL_MAX_GEOMETRY_TEXTURE_IMAGE_UNITS_EXT
_m[0x8DE1] = (1,) # GL_MAX_GEOMETRY_TOTAL_OUTPUT_COMPONENTS
_m[0x8DE1] = (1,) # GL_MAX_GEOMETRY_TOTAL_OUTPUT_COMPONENTS_ARB
_m[0x8DE1] = (1,) # GL_MAX_GEOMETRY_TOTAL_OUTPUT_COMPONENTS_EXT
_m[0x8A2C] = (1,) # GL_MAX_GEOMETRY_UNIFORM_BLOCKS
_m[0x8DDF] = (1,) # GL_MAX_GEOMETRY_UNIFORM_COMPONENTS
_m[0x8DDF] = (1,) # GL_MAX_GEOMETRY_UNIFORM_COMPONENTS_ARB
_m[0x8DDF] = (1,) # GL_MAX_GEOMETRY_UNIFORM_COMPONENTS_EXT
_m[0x8DDD] = (1,) # GL_MAX_GEOMETRY_VARYING_COMPONENTS_ARB
_m[0x8DDD] = (1,) # GL_MAX_GEOMETRY_VARYING_COMPONENTS_EXT
_m[0x827F] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_MAX_HEIGHT
_m[0x906D] = (1,) # GL_MAX_IMAGE_SAMPLES
_m[0x906D] = (1,) # GL_MAX_IMAGE_SAMPLES_EXT
_m[0x8F38] = (1,) # GL_MAX_IMAGE_UNITS
_m[0x8F38] = (1,) # GL_MAX_IMAGE_UNITS_EXT
_m[0x9110] = (1,) # GL_MAX_INTEGER_SAMPLES
_m[0x82E8] = (1,) # GL_MAX_LABEL_LENGTH
_m[0x8281] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_MAX_LAYERS
_m[0x0D31] = (1,) # GL_MAX_LIGHTS
_m[0x0B31] = (1,) # GL_MAX_LIST_NESTING
_m[0x86D6] = (1,) # GL_MAX_MAP_TESSELLATION_NV
_m[0x8841] = (1,) # GL_MAX_MATRIX_PALETTE_STACK_DEPTH_ARB
_m[0x0D36] = (1,) # GL_MAX_MODELVIEW_STACK_DEPTH
_m[0x8E11] = (1,) # GL_MAX_MULTISAMPLE_COVERAGE_MODES_NV
_m[0x92F6] = (1,) # GL_MAX_NAME_LENGTH
_m[0x0D37] = (1,) # GL_MAX_NAME_STACK_DEPTH
_m[0x92F7] = (1,) # GL_MAX_NUM_ACTIVE_VARIABLES
_m[0x92F8] = (1,) # GL_MAX_NUM_COMPATIBLE_SUBROUTINES
_m[0x87CA] = (1,) # GL_MAX_OPTIMIZED_VERTEX_SHADER_INSTRUCTIONS_EXT
_m[0x87CE] = (1,) # GL_MAX_OPTIMIZED_VERTEX_SHADER_LOCALS_EXT
_m[0x87CC] = (1,) # GL_MAX_OPTIMIZED_VERTEX_SHADER_LOCAL_CONSTANTS_EXT
_m[0x87CB] = (1,) # GL_MAX_OPTIMIZED_VERTEX_SHADER_VARIANTS_EXT
_m[0x8842] = (1,) # GL_MAX_PALETTE_MATRICES_ARB
_m[0x8E7D] = (1,) # GL_MAX_PATCH_VERTICES
_m[0x0D34] = (1,) # GL_MAX_PIXEL_MAP_TABLE
_m[0x8337] = (1,) # GL_MAX_PIXEL_TRANSFORM_2D_STACK_DEPTH_EXT
_m[0x87F1] = (1,) # GL_MAX_PN_TRIANGLES_TESSELATION_LEVEL_ATI
_m[0x88B1] = (1,) # GL_MAX_PROGRAM_ADDRESS_REGISTERS_ARB
_m[0x880B] = (1,) # GL_MAX_PROGRAM_ALU_INSTRUCTIONS_ARB
_m[0x88AD] = (1,) # GL_MAX_PROGRAM_ATTRIBS_ARB
_m[0x8908] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/gpu_program4.txt # GL_MAX_PROGRAM_ATTRIB_COMPONENTS_NV
_m[0x88F5] = (1,) # GL_MAX_PROGRAM_CALL_DEPTH_NV
_m[0x88B5] = (1,) # GL_MAX_PROGRAM_ENV_PARAMETERS_ARB
_m[0x88F4] = (1,) # GL_MAX_PROGRAM_EXEC_INSTRUCTIONS_NV
_m[0x8DA5] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/gpu_program4.txt # GL_MAX_PROGRAM_GENERIC_ATTRIBS_NV
_m[0x8DA6] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/gpu_program4.txt # GL_MAX_PROGRAM_GENERIC_RESULTS_NV
_m[0x88F6] = (1,) # GL_MAX_PROGRAM_IF_DEPTH_NV
_m[0x88A1] = (1,) # GL_MAX_PROGRAM_INSTRUCTIONS_ARB
_m[0x88B4] = (1,) # GL_MAX_PROGRAM_LOCAL_PARAMETERS_ARB
_m[0x88F8] = (1,) # GL_MAX_PROGRAM_LOOP_COUNT_NV
_m[0x88F7] = (1,) # GL_MAX_PROGRAM_LOOP_DEPTH_NV
_m[0x862F] = (1,) # GL_MAX_PROGRAM_MATRICES_ARB
_m[0x862E] = (1,) # GL_MAX_PROGRAM_MATRIX_STACK_DEPTH_ARB
_m[0x88B3] = (1,) # GL_MAX_PROGRAM_NATIVE_ADDRESS_REGISTERS_ARB
_m[0x880E] = (1,) # GL_MAX_PROGRAM_NATIVE_ALU_INSTRUCTIONS_ARB
_m[0x88AF] = (1,) # GL_MAX_PROGRAM_NATIVE_ATTRIBS_ARB
_m[0x88A3] = (1,) # GL_MAX_PROGRAM_NATIVE_INSTRUCTIONS_ARB
_m[0x88AB] = (1,) # GL_MAX_PROGRAM_NATIVE_PARAMETERS_ARB
_m[0x88A7] = (1,) # GL_MAX_PROGRAM_NATIVE_TEMPORARIES_ARB
_m[0x8810] = (1,) # GL_MAX_PROGRAM_NATIVE_TEX_INDIRECTIONS_ARB
_m[0x880F] = (1,) # GL_MAX_PROGRAM_NATIVE_TEX_INSTRUCTIONS_ARB
_m[0x8C27] = (1,) # GL_MAX_PROGRAM_OUTPUT_VERTICES_NV
_m[0x88A9] = (1,) # GL_MAX_PROGRAM_PARAMETERS_ARB
_m[0x8DA0] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/parameter_buffer_object.txt # GL_MAX_PROGRAM_PARAMETER_BUFFER_BINDINGS_NV
_m[0x8DA1] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/parameter_buffer_object.txt # GL_MAX_PROGRAM_PARAMETER_BUFFER_SIZE_NV
_m[0x86D8] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/tessellation_program5.txt # GL_MAX_PROGRAM_PATCH_ATTRIBS_NV
_m[0x8909] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/gpu_program4.txt # GL_MAX_PROGRAM_RESULT_COMPONENTS_NV
_m[0x88A5] = (1,) # GL_MAX_PROGRAM_TEMPORARIES_ARB
_m[0x8905] = (1,) # GL_MAX_PROGRAM_TEXEL_OFFSET
_m[0x8F9F] = (1,) # GL_MAX_PROGRAM_TEXTURE_GATHER_COMPONENTS_ARB
_m[0x8E5F] = (1,) # GL_MAX_PROGRAM_TEXTURE_GATHER_OFFSET_ARB
_m[0x8E5F] = (1,) # GL_MAX_PROGRAM_TEXTURE_GATHER_OFFSET_NV
_m[0x880D] = (1,) # GL_MAX_PROGRAM_TEX_INDIRECTIONS_ARB
_m[0x880C] = (1,) # GL_MAX_PROGRAM_TEX_INSTRUCTIONS_ARB
_m[0x8C28] = (1,) # GL_MAX_PROGRAM_TOTAL_OUTPUT_COMPONENTS_NV
_m[0x0D38] = (1,) # GL_MAX_PROJECTION_STACK_DEPTH
_m[0x86D7] = (1,) # GL_MAX_RATIONAL_EVAL_ORDER_NV
_m[0x84F8] = (1,) # GL_MAX_RECTANGLE_TEXTURE_SIZE
_m[0x84F8] = (1,) # GL_MAX_RECTANGLE_TEXTURE_SIZE_ARB
_m[0x84F8] = (1,) # GL_MAX_RECTANGLE_TEXTURE_SIZE_NV
_m[0x84E8] = (1,) # GL_MAX_RENDERBUFFER_SIZE
_m[0x84E8] = (1,) # GL_MAX_RENDERBUFFER_SIZE_EXT
_m[0x8D57] = (1,) # GL_MAX_SAMPLES
_m[0x8D57] = (1,) # GL_MAX_SAMPLES_EXT
_m[0x8E59] = (1,) # GL_MAX_SAMPLE_MASK_WORDS
_m[0x8E59] = (1,) # GL_MAX_SAMPLE_MASK_WORDS_NV
_m[0x9111] = (1,) # GL_MAX_SERVER_WAIT_TIMEOUT
_m[0x90DE] = (1,) # GL_MAX_SHADER_STORAGE_BLOCK_SIZE
_m[0x90DD] = (1,) # GL_MAX_SHADER_STORAGE_BUFFER_BINDINGS
_m[0x8504] = (1,) # GL_MAX_SHININESS_NV
_m[0x9199] = (1,)#TODO Review http://www.opengl.org/registry/specs//AMD/sparse_texture.txt # GL_MAX_SPARSE_3D_TEXTURE_SIZE_AMD
_m[0x9199] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/sparse_texture.txt # GL_MAX_SPARSE_3D_TEXTURE_SIZE_ARB
_m[0x919A] = (1,) # GL_MAX_SPARSE_ARRAY_TEXTURE_LAYERS
_m[0x9198] = (1,)#TODO Review http://www.opengl.org/registry/specs//AMD/sparse_texture.txt # GL_MAX_SPARSE_TEXTURE_SIZE_AMD
_m[0x9198] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/sparse_texture.txt # GL_MAX_SPARSE_TEXTURE_SIZE_ARB
_m[0x8505] = (1,) # GL_MAX_SPOT_EXPONENT_NV
_m[0x8DE7] = (1,) # GL_MAX_SUBROUTINES
_m[0x8DE8] = (1,) # GL_MAX_SUBROUTINE_UNIFORM_LOCATIONS
_m[0x92D3] = (1,) # GL_MAX_TESS_CONTROL_ATOMIC_COUNTERS
_m[0x92CD] = (1,) # GL_MAX_TESS_CONTROL_ATOMIC_COUNTER_BUFFERS
_m[0x90CB] = (1,) # GL_MAX_TESS_CONTROL_IMAGE_UNIFORMS
_m[0x886C] = (1,) # GL_MAX_TESS_CONTROL_INPUT_COMPONENTS
_m[0x8E83] = (1,) # GL_MAX_TESS_CONTROL_OUTPUT_COMPONENTS
_m[0x90D8] = (1,) # GL_MAX_TESS_CONTROL_SHADER_STORAGE_BLOCKS
_m[0x8E81] = (1,) # GL_MAX_TESS_CONTROL_TEXTURE_IMAGE_UNITS
_m[0x8E85] = (1,) # GL_MAX_TESS_CONTROL_TOTAL_OUTPUT_COMPONENTS
_m[0x8E89] = (1,) # GL_MAX_TESS_CONTROL_UNIFORM_BLOCKS
_m[0x8E7F] = (1,) # GL_MAX_TESS_CONTROL_UNIFORM_COMPONENTS
_m[0x92D4] = (1,) # GL_MAX_TESS_EVALUATION_ATOMIC_COUNTERS
_m[0x92CE] = (1,) # GL_MAX_TESS_EVALUATION_ATOMIC_COUNTER_BUFFERS
_m[0x90CC] = (1,) # GL_MAX_TESS_EVALUATION_IMAGE_UNIFORMS
_m[0x886D] = (1,) # GL_MAX_TESS_EVALUATION_INPUT_COMPONENTS
_m[0x8E86] = (1,) # GL_MAX_TESS_EVALUATION_OUTPUT_COMPONENTS
_m[0x90D9] = (1,) # GL_MAX_TESS_EVALUATION_SHADER_STORAGE_BLOCKS
_m[0x8E82] = (1,) # GL_MAX_TESS_EVALUATION_TEXTURE_IMAGE_UNITS
_m[0x8E8A] = (1,) # GL_MAX_TESS_EVALUATION_UNIFORM_BLOCKS
_m[0x8E80] = (1,) # GL_MAX_TESS_EVALUATION_UNIFORM_COMPONENTS
_m[0x8E7E] = (1,) # GL_MAX_TESS_GEN_LEVEL
_m[0x8E84] = (1,) # GL_MAX_TESS_PATCH_COMPONENTS
_m[0x8C2B] = (1,) # GL_MAX_TEXTURE_BUFFER_SIZE
_m[0x8C2B] = (1,) # GL_MAX_TEXTURE_BUFFER_SIZE_ARB
_m[0x8C2B] = (1,) # GL_MAX_TEXTURE_BUFFER_SIZE_EXT
_m[0x8871] = (1,) # GL_MAX_TEXTURE_COORDS
_m[0x8871] = (1,) # GL_MAX_TEXTURE_COORDS_ARB
_m[0x8871] = (1,) # GL_MAX_TEXTURE_COORDS_NV
_m[0x8872] = (1,) # GL_MAX_TEXTURE_IMAGE_UNITS
_m[0x8872] = (1,) # GL_MAX_TEXTURE_IMAGE_UNITS_ARB
_m[0x8872] = (1,) # GL_MAX_TEXTURE_IMAGE_UNITS_NV
_m[0x84FD] = (1,) # GL_MAX_TEXTURE_LOD_BIAS
_m[0x84FD] = (1,) # GL_MAX_TEXTURE_LOD_BIAS_EXT
_m[0x84FF] = (1,) # GL_MAX_TEXTURE_MAX_ANISOTROPY_EXT
_m[0x0D33] = (1,) # GL_MAX_TEXTURE_SIZE
_m[0x0D39] = (1,) # GL_MAX_TEXTURE_STACK_DEPTH
_m[0x84E2] = (1,) # GL_MAX_TEXTURE_UNITS
_m[0x84E2] = (1,) # GL_MAX_TEXTURE_UNITS_ARB
_m[0x862F] = (1,) # GL_MAX_TRACK_MATRICES_NV
_m[0x862E] = (1,) # GL_MAX_TRACK_MATRIX_STACK_DEPTH_NV
_m[0x8E70] = (1,) # GL_MAX_TRANSFORM_FEEDBACK_BUFFERS
_m[0x8A30] = (1,) # GL_MAX_UNIFORM_BLOCK_SIZE
_m[0x8A2F] = (1,) # GL_MAX_UNIFORM_BUFFER_BINDINGS
_m[0x826E] = (1,) # GL_MAX_UNIFORM_LOCATIONS
_m[0x8B4B] = (1,) # GL_MAX_VARYING_COMPONENTS
_m[0x8B4B] = (1,) # GL_MAX_VARYING_COMPONENTS_EXT
_m[0x8B4B] = (1,) # GL_MAX_VARYING_FLOATS
_m[0x8B4B] = (1,) # GL_MAX_VARYING_FLOATS_ARB
_m[0x8DFC] = (1,) # GL_MAX_VARYING_VECTORS
_m[0x8520] = (1,) # GL_MAX_VERTEX_ARRAY_RANGE_ELEMENT_NV
_m[0x92D2] = (1,) # GL_MAX_VERTEX_ATOMIC_COUNTERS
_m[0x92CC] = (1,) # GL_MAX_VERTEX_ATOMIC_COUNTER_BUFFERS
_m[0x8869] = (1,) # GL_MAX_VERTEX_ATTRIBS
_m[0x8869] = (1,) # GL_MAX_VERTEX_ATTRIBS_ARB
_m[0x82DA] = (1,) # GL_MAX_VERTEX_ATTRIB_BINDINGS
_m[0x82D9] = (1,) # GL_MAX_VERTEX_ATTRIB_RELATIVE_OFFSET
_m[0x8DE2] = (1,) # GL_MAX_VERTEX_BINDABLE_UNIFORMS_EXT
_m[0x90CA] = (1,) # GL_MAX_VERTEX_IMAGE_UNIFORMS
_m[0x87C5] = (1,) # GL_MAX_VERTEX_SHADER_INSTRUCTIONS_EXT
_m[0x87C7] = (1,) # GL_MAX_VERTEX_SHADER_INVARIANTS_EXT
_m[0x87C9] = (1,) # GL_MAX_VERTEX_SHADER_LOCALS_EXT
_m[0x87C8] = (1,) # GL_MAX_VERTEX_SHADER_LOCAL_CONSTANTS_EXT
_m[0x90D6] = (1,) # GL_MAX_VERTEX_SHADER_STORAGE_BLOCKS
_m[0x87C6] = (1,) # GL_MAX_VERTEX_SHADER_VARIANTS_EXT
_m[0x8E71] = (1,) # GL_MAX_VERTEX_STREAMS
_m[0x876B] = (1,) # GL_MAX_VERTEX_STREAMS_ATI
_m[0x8B4C] = (1,) # GL_MAX_VERTEX_TEXTURE_IMAGE_UNITS
_m[0x8B4C] = (1,) # GL_MAX_VERTEX_TEXTURE_IMAGE_UNITS_ARB
_m[0x8A2B] = (1,) # GL_MAX_VERTEX_UNIFORM_BLOCKS
_m[0x8B4A] = (1,) # GL_MAX_VERTEX_UNIFORM_COMPONENTS
_m[0x8B4A] = (1,) # GL_MAX_VERTEX_UNIFORM_COMPONENTS_ARB
_m[0x8DFB] = (1,) # GL_MAX_VERTEX_UNIFORM_VECTORS
_m[0x86A4] = (1,) # GL_MAX_VERTEX_UNITS_ARB
_m[0x8DDE] = (1,) # GL_MAX_VERTEX_VARYING_COMPONENTS_ARB
_m[0x8DDE] = (1,) # GL_MAX_VERTEX_VARYING_COMPONENTS_EXT
_m[0x825B] = (1,) # GL_MAX_VIEWPORTS
_m[0x0D3A] = (2,) # GL_MAX_VIEWPORT_DIMS
_m[0x827E] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_MAX_WIDTH
_m[0x802E] = (1,) # GL_MINMAX
_m[0x802E] = (1,) # GL_MINMAX_EXT
_m[0x802F] = (1,) # GL_MINMAX_FORMAT
_m[0x802F] = (1,) # GL_MINMAX_FORMAT_EXT
_m[0x8030] = (1,) # GL_MINMAX_SINK
_m[0x8030] = (1,) # GL_MINMAX_SINK_EXT
_m[0x821C] = (1,) # GL_MINOR_VERSION
_m[0x8E5B] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/gpu_shader5.txt # GL_MIN_FRAGMENT_INTERPOLATION_OFFSET
_m[0x8E5B] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/gpu_program5.txt # GL_MIN_FRAGMENT_INTERPOLATION_OFFSET_NV
_m[0x90BC] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/map_buffer_alignment.txt # GL_MIN_MAP_BUFFER_ALIGNMENT
_m[0x8904] = (1,) # GL_MIN_PROGRAM_TEXEL_OFFSET
_m[0x8E5E] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/texture_gather.txt # GL_MIN_PROGRAM_TEXTURE_GATHER_OFFSET_ARB
_m[0x8E5E] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/gpu_program5.txt # GL_MIN_PROGRAM_TEXTURE_GATHER_OFFSET_NV
_m[0x8C37] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/sample_shading.txt # GL_MIN_SAMPLE_SHADING_VALUE_ARB
_m[0x919B] = (1,)#TODO Review http://www.opengl.org/registry/specs//AMD/sparse_texture.txt # GL_MIN_SPARSE_LEVEL_AMD
_m[0x8293] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_MIPMAP
_m[0x0BA6] = (4,4) # GL_MODELVIEW0_MATRIX_EXT
_m[0x0BA3] = (1,) # GL_MODELVIEW0_STACK_DEPTH_EXT
_m[0x872A] = (4,4) # GL_MODELVIEW10_ARB
_m[0x872B] = (4,4) # GL_MODELVIEW11_ARB
_m[0x872C] = (4,4) # GL_MODELVIEW12_ARB
_m[0x872D] = (4,4) # GL_MODELVIEW13_ARB
_m[0x872E] = (4,4) # GL_MODELVIEW14_ARB
_m[0x872F] = (4,4) # GL_MODELVIEW15_ARB
_m[0x8730] = (4,4) # GL_MODELVIEW16_ARB
_m[0x8731] = (4,4) # GL_MODELVIEW17_ARB
_m[0x8732] = (4,4) # GL_MODELVIEW18_ARB
_m[0x8733] = (4,4) # GL_MODELVIEW19_ARB
_m[0x850A] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/vertex_blend.txt # GL_MODELVIEW1_ARB
_m[0x8506] = (4,4) # GL_MODELVIEW1_MATRIX_EXT
_m[0x8502] = (1,) # GL_MODELVIEW1_STACK_DEPTH_EXT
_m[0x8734] = (4,4) # GL_MODELVIEW20_ARB
_m[0x8735] = (4,4) # GL_MODELVIEW21_ARB
_m[0x8736] = (4,4) # GL_MODELVIEW22_ARB
_m[0x8737] = (4,4) # GL_MODELVIEW23_ARB
_m[0x8738] = (4,4) # GL_MODELVIEW24_ARB
_m[0x8739] = (4,4) # GL_MODELVIEW25_ARB
_m[0x873A] = (4,4) # GL_MODELVIEW26_ARB
_m[0x873B] = (4,4) # GL_MODELVIEW27_ARB
_m[0x873C] = (4,4) # GL_MODELVIEW28_ARB
_m[0x873D] = (4,4) # GL_MODELVIEW29_ARB
_m[0x8722] = (4,4) # GL_MODELVIEW2_ARB
_m[0x873E] = (4,4) # GL_MODELVIEW30_ARB
_m[0x873F] = (4,4) # GL_MODELVIEW31_ARB
_m[0x8723] = (4,4) # GL_MODELVIEW3_ARB
_m[0x8724] = (4,4) # GL_MODELVIEW4_ARB
_m[0x8725] = (4,4) # GL_MODELVIEW5_ARB
_m[0x8726] = (4,4) # GL_MODELVIEW6_ARB
_m[0x8727] = (4,4) # GL_MODELVIEW7_ARB
_m[0x8728] = (4,4) # GL_MODELVIEW8_ARB
_m[0x8729] = (4,4) # GL_MODELVIEW9_ARB
_m[0x0BA6] = (4, 4) # GL_MODELVIEW_MATRIX
_m[0x0BA3] = (1,) # GL_MODELVIEW_STACK_DEPTH
_m[0x809D] = (1,) # GL_MULTISAMPLE
_m[0x86B2] = (1,) # GL_MULTISAMPLE_3DFX
_m[0x809D] = (1,) # GL_MULTISAMPLE_ARB
_m[0x8E12] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/framebuffer_multisample_coverage.txt # GL_MULTISAMPLE_COVERAGE_MODES_NV
_m[0x809D] = (1,) # GL_MULTISAMPLE_EXT
_m[0x8534] = (1,) # GL_MULTISAMPLE_FILTER_HINT_NV
_m[0x809D] = (1,) # GL_MULTISAMPLE_SGIS
_m[0x8DE9] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/shading_language_include.txt # GL_NAMED_STRING_LENGTH_ARB
_m[0x8DEA] = (1,) # GL_NAMED_STRING_TYPE_ARB
_m[0x92F9] = (1,) # GL_NAME_LENGTH
_m[0x0D70] = (1,) # GL_NAME_STACK_DEPTH
_m[0x9025] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/video_capture.txt # GL_NEXT_VIDEO_CAPTURE_BUFFER_STATUS_NV
_m[0x0BA1] = (1,) # GL_NORMALIZE
_m[0x8075] = (1,) # GL_NORMAL_ARRAY
_m[0x8897] = (1,) # GL_NORMAL_ARRAY_BUFFER_BINDING
_m[0x8897] = (1,) # GL_NORMAL_ARRAY_BUFFER_BINDING_ARB
_m[0x8080] = (1,) # GL_NORMAL_ARRAY_COUNT_EXT
_m[0x8075] = (1,) # GL_NORMAL_ARRAY_EXT
_m[0x8F2C] = (1,) # GL_NORMAL_ARRAY_LENGTH_NV
_m[0x83F6] = (1,)#TODO Review http://www.opengl.org/registry/specs//INTEL/parallel_arrays.txt # GL_NORMAL_ARRAY_PARALLEL_POINTERS_INTEL
_m[0x808F] = (1,) # GL_NORMAL_ARRAY_POINTER
_m[0x807F] = (1,) # GL_NORMAL_ARRAY_STRIDE
_m[0x807F] = (1,) # GL_NORMAL_ARRAY_STRIDE_EXT
_m[0x807E] = (1,) # GL_NORMAL_ARRAY_TYPE
_m[0x807E] = (1,) # GL_NORMAL_ARRAY_TYPE_EXT
_m[0x8261] = (1,)#TODO Review http://www.opengl.org/registry/specs//KHR/robustness.txt # GL_NO_RESET_NOTIFICATION
_m[0x8261] = (1,) # GL_NO_RESET_NOTIFICATION_ARB
_m[0x9304] = (1,) # GL_NUM_ACTIVE_VARIABLES
_m[0x8E4A] = (1,) # GL_NUM_COMPATIBLE_SUBROUTINES
_m[0x86A2] = (1,) # GL_NUM_COMPRESSED_TEXTURE_FORMATS
_m[0x86A2] = (1,) # GL_NUM_COMPRESSED_TEXTURE_FORMATS_ARB
_m[0x821D] = (1,) # GL_NUM_EXTENSIONS
_m[0x8E29] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/present_video.txt # GL_NUM_FILL_STREAMS_NV
_m[0x896F] = (1,) # GL_NUM_FRAGMENT_CONSTANTS_ATI
_m[0x896E] = (1,) # GL_NUM_FRAGMENT_REGISTERS_ATI
_m[0x854E] = (1,) # GL_NUM_GENERAL_COMBINERS_NV
_m[0x8973] = (1,) # GL_NUM_INPUT_INTERPOLATOR_COMPONENTS_ATI
_m[0x8971] = (1,) # GL_NUM_INSTRUCTIONS_PER_PASS_ATI
_m[0x8972] = (1,) # GL_NUM_INSTRUCTIONS_TOTAL_ATI
_m[0x8974] = (1,) # GL_NUM_LOOPBACK_COMPONENTS_ATI
_m[0x8970] = (1,) # GL_NUM_PASSES_ATI
_m[0x87FE] = (1,) # GL_NUM_PROGRAM_BINARY_FORMATS
_m[0x9380] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query.txt # GL_NUM_SAMPLE_COUNTS
_m[0x8DF9] = (1,) # GL_NUM_SHADER_BINARY_FORMATS
_m[0x91AA] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/sparse_texture.txt # GL_NUM_SPARSE_LEVELS_ARB
_m[0x9024] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/video_capture.txt # GL_NUM_VIDEO_CAPTURE_STREAMS_NV
_m[0x8B86] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/shader_objects.txt # GL_OBJECT_ACTIVE_UNIFORMS_ARB
_m[0x8B87] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/shader_objects.txt # GL_OBJECT_ACTIVE_UNIFORM_MAX_LENGTH_ARB
_m[0x8B85] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/shader_objects.txt # GL_OBJECT_ATTACHED_OBJECTS_ARB
_m[0x8764] = (1,) # GL_OBJECT_BUFFER_SIZE_ATI
_m[0x8765] = (4,) # GL_OBJECT_BUFFER_USAGE_ATI
_m[0x8B81] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/shader_objects.txt # GL_OBJECT_COMPILE_STATUS_ARB
_m[0x8B80] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/shader_objects.txt # GL_OBJECT_DELETE_STATUS_ARB
_m[0x8B84] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/shader_objects.txt # GL_OBJECT_INFO_LOG_LENGTH_ARB
_m[0x81F7] = (7,) # GL_OBJECT_LINE_SGIS
_m[0x8B82] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/shader_objects.txt # GL_OBJECT_LINK_STATUS_ARB
_m[0x2501] = (4,) # GL_OBJECT_PLANE
_m[0x81F5] = (4,) # GL_OBJECT_POINT_SGIS
_m[0x8B88] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/shader_objects.txt # GL_OBJECT_SHADER_SOURCE_LENGTH_ARB
_m[0x8B4F] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/shader_objects.txt # GL_OBJECT_SUBTYPE_ARB
_m[0x9112] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/sync.txt # GL_OBJECT_TYPE
_m[0x8B4E] = (1,) # GL_OBJECT_TYPE_ARB
_m[0x8B83] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/shader_objects.txt # GL_OBJECT_VALIDATE_STATUS_ARB
_m[0x8165] = (1,) # GL_OCCLUSION_TEST_HP
_m[0x8166] = (1,) # GL_OCCLUSION_TEST_RESULT_HP
_m[0x92FC] = (1,) # GL_OFFSET
_m[0x86E3] = (1,) # GL_OFFSET_TEXTURE_BIAS_NV
_m[0x86E1] = (4,) # GL_OFFSET_TEXTURE_MATRIX_NV
_m[0x86E2] = (1,) # GL_OFFSET_TEXTURE_SCALE_NV
_m[0x8598] = (1,) # GL_OPERAND0_ALPHA
_m[0x8590] = (1,) # GL_OPERAND0_RGB
_m[0x8599] = (1,) # GL_OPERAND1_ALPHA
_m[0x8591] = (1,) # GL_OPERAND1_RGB
_m[0x859A] = (1,) # GL_OPERAND2_ALPHA
_m[0x8592] = (1,) # GL_OPERAND2_RGB
_m[0x859B] = (1,) # GL_OPERAND3_ALPHA_NV
_m[0x8593] = (1,) # GL_OPERAND3_RGB_NV
_m[0x0D05] = (1,) # GL_PACK_ALIGNMENT
_m[0x800E] = (1,) # GL_PACK_CMYK_HINT_EXT
_m[0x912D] = (1,) # GL_PACK_COMPRESSED_BLOCK_DEPTH
_m[0x912C] = (1,) # GL_PACK_COMPRESSED_BLOCK_HEIGHT
_m[0x912E] = (1,) # GL_PACK_COMPRESSED_BLOCK_SIZE
_m[0x912B] = (1,) # GL_PACK_COMPRESSED_BLOCK_WIDTH
_m[0x8131] = (1,) # GL_PACK_IMAGE_DEPTH_SGIS
_m[0x806C] = (1,) # GL_PACK_IMAGE_HEIGHT
_m[0x806C] = (1,) # GL_PACK_IMAGE_HEIGHT_EXT
_m[0x8758] = (1,) # GL_PACK_INVERT_MESA
_m[0x0D01] = (1,) # GL_PACK_LSB_FIRST
_m[0x8984] = (1,) # GL_PACK_RESAMPLE_OML
_m[0x842E] = (1,) # GL_PACK_RESAMPLE_SGIX
_m[0x8A15] = (1,) # GL_PACK_ROW_BYTES_APPLE
_m[0x0D02] = (1,) # GL_PACK_ROW_LENGTH
_m[0x806B] = (1,) # GL_PACK_SKIP_IMAGES
_m[0x806B] = (1,) # GL_PACK_SKIP_IMAGES_EXT
_m[0x0D04] = (1,) # GL_PACK_SKIP_PIXELS
_m[0x0D03] = (1,) # GL_PACK_SKIP_ROWS
_m[0x8130] = (1,) # GL_PACK_SKIP_VOLUMES_SGIS
_m[0x0D00] = (1,) # GL_PACK_SWAP_BYTES
_m[0x83F4] = (1,) # GL_PARALLEL_ARRAYS_INTEL
_m[0x80EF] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/indirect_parameters.txt # GL_PARAMETER_BUFFER_BINDING_ARB
_m[0x8E73] = (1,) # GL_PATCH_DEFAULT_INNER_LEVEL
_m[0x8E74] = (1,) # GL_PATCH_DEFAULT_OUTER_LEVEL
_m[0x8E72] = (1,) # GL_PATCH_VERTICES
_m[0x909D] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/path_rendering.txt # GL_PATH_COMMAND_COUNT_NV
_m[0x90A0] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/path_rendering.txt # GL_PATH_COMPUTED_LENGTH_NV
_m[0x909E] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/path_rendering.txt # GL_PATH_COORD_COUNT_NV
_m[0x90BF] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/path_rendering.txt # GL_PATH_COVER_DEPTH_FUNC_NV
_m[0x909F] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/path_rendering.txt # GL_PATH_DASH_ARRAY_COUNT_NV
_m[0x90AB] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/path_rendering.txt # GL_PATH_ERROR_POSITION_NV
_m[0x90A1] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/path_rendering.txt # GL_PATH_FILL_BOUNDING_BOX_NV
_m[0x90AC] = (1,) # GL_PATH_FOG_GEN_MODE_NV
_m[0x90B1] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/path_rendering.txt # GL_PATH_GEN_COEFF_NV
_m[0x90B2] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/path_rendering.txt # GL_PATH_GEN_COLOR_FORMAT_NV
_m[0x90B3] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/path_rendering.txt # GL_PATH_GEN_COMPONENTS_NV
_m[0x90B0] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/path_rendering.txt # GL_PATH_GEN_MODE_NV
_m[0x90BD] = (1,) # GL_PATH_STENCIL_DEPTH_OFFSET_FACTOR_NV
_m[0x90BE] = (1,) # GL_PATH_STENCIL_DEPTH_OFFSET_UNITS_NV
_m[0x90B7] = (1,) # GL_PATH_STENCIL_FUNC_NV
_m[0x90B8] = (1,) # GL_PATH_STENCIL_REF_NV
_m[0x90B9] = (1,) # GL_PATH_STENCIL_VALUE_MASK_NV
_m[0x90A2] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/path_rendering.txt # GL_PATH_STROKE_BOUNDING_BOX_NV
_m[0x8BC6] = (1,)#TODO Review http://www.opengl.org/registry/specs//AMD/performance_monitor.txt # GL_PERFMON_RESULT_AMD
_m[0x8BC4] = (1,)#TODO Review http://www.opengl.org/registry/specs//AMD/performance_monitor.txt # GL_PERFMON_RESULT_AVAILABLE_AMD
_m[0x8BC5] = (1,)#TODO Review http://www.opengl.org/registry/specs//AMD/performance_monitor.txt # GL_PERFMON_RESULT_SIZE_AMD
_m[0x94FF] = (1,)#TODO Review http://www.opengl.org/registry/specs//INTEL/performance_query.txt # GL_PERFQUERY_COUNTER_DESC_LENGTH_MAX_INTEL
_m[0x94FE] = (1,)#TODO Review http://www.opengl.org/registry/specs//INTEL/performance_query.txt # GL_PERFQUERY_COUNTER_NAME_LENGTH_MAX_INTEL
_m[0x9500] = (1,)#TODO Review http://www.opengl.org/registry/specs//INTEL/performance_query.txt # GL_PERFQUERY_GPA_EXTENDED_COUNTERS_INTEL
_m[0x94FD] = (1,)#TODO Review http://www.opengl.org/registry/specs//INTEL/performance_query.txt # GL_PERFQUERY_QUERY_NAME_LENGTH_MAX_INTEL
_m[0x0C50] = (1,) # GL_PERSPECTIVE_CORRECTION_HINT
_m[0x8535] = (1,) # GL_PER_STAGE_CONSTANTS_NV
_m[0x8864] = (1,) # GL_PIXEL_COUNTER_BITS_NV
_m[0x8867] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/occlusion_query.txt # GL_PIXEL_COUNT_AVAILABLE_NV
_m[0x8866] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/occlusion_query.txt # GL_PIXEL_COUNT_NV
_m[0x8355] = (1,) # GL_PIXEL_FRAGMENT_ALPHA_SOURCE_SGIS
_m[0x8354] = (1,) # GL_PIXEL_FRAGMENT_RGB_SOURCE_SGIS
_m[0x8356] = (1,) # GL_PIXEL_GROUP_COLOR_SGIS
_m[0x0C79] = (_L(0xCB9),) # GL_PIXEL_MAP_A_TO_A
_m[0x0CB9] = (1,) # GL_PIXEL_MAP_A_TO_A_SIZE
_m[0x0C78] = (_L(0xCB8),) # GL_PIXEL_MAP_B_TO_B
_m[0x0CB8] = (1,) # GL_PIXEL_MAP_B_TO_B_SIZE
_m[0x0C77] = (_L(0xCB7),) # GL_PIXEL_MAP_G_TO_G
_m[0x0CB7] = (1,) # GL_PIXEL_MAP_G_TO_G_SIZE
_m[0x0C75] = (_L(0xCB5),) # GL_PIXEL_MAP_I_TO_A
_m[0x0CB5] = (1,) # GL_PIXEL_MAP_I_TO_A_SIZE
_m[0x0C74] = (_L(0xCB4),) # GL_PIXEL_MAP_I_TO_B
_m[0x0CB4] = (1,) # GL_PIXEL_MAP_I_TO_B_SIZE
_m[0x0C73] = (_L(0xCB3),) # GL_PIXEL_MAP_I_TO_G
_m[0x0CB3] = (1,) # GL_PIXEL_MAP_I_TO_G_SIZE
_m[0x0C70] = (_L(0xCB0),) # GL_PIXEL_MAP_I_TO_I
_m[0x0CB0] = (1,) # GL_PIXEL_MAP_I_TO_I_SIZE
_m[0x0C72] = (_L(0xCB2),) # GL_PIXEL_MAP_I_TO_R
_m[0x0CB2] = (1,) # GL_PIXEL_MAP_I_TO_R_SIZE
_m[0x0C76] = (_L(0xCB6),) # GL_PIXEL_MAP_R_TO_R
_m[0x0CB6] = (1,) # GL_PIXEL_MAP_R_TO_R_SIZE
_m[0x0C71] = (_L(0xCB1),) # GL_PIXEL_MAP_S_TO_S
_m[0x0CB1] = (1,) # GL_PIXEL_MAP_S_TO_S_SIZE
_m[0x88ED] = (1,) # GL_PIXEL_PACK_BUFFER_BINDING
_m[0x88ED] = (1,) # GL_PIXEL_PACK_BUFFER_BINDING_ARB
_m[0x88ED] = (1,) # GL_PIXEL_PACK_BUFFER_BINDING_EXT
_m[0x8353] = (1,) # GL_PIXEL_TEXTURE_SGIS
_m[0x832B] = (1,) # GL_PIXEL_TEX_GEN_MODE_SGIX
_m[0x8139] = (1,) # GL_PIXEL_TEX_GEN_SGIX
_m[0x813E] = (1,) # GL_PIXEL_TILE_BEST_ALIGNMENT_SGIX
_m[0x813F] = (1,) # GL_PIXEL_TILE_CACHE_INCREMENT_SGIX
_m[0x8145] = (1,) # GL_PIXEL_TILE_CACHE_SIZE_SGIX
_m[0x8144] = (1,) # GL_PIXEL_TILE_GRID_DEPTH_SGIX
_m[0x8143] = (1,) # GL_PIXEL_TILE_GRID_HEIGHT_SGIX
_m[0x8142] = (1,) # GL_PIXEL_TILE_GRID_WIDTH_SGIX
_m[0x8141] = (1,) # GL_PIXEL_TILE_HEIGHT_SGIX
_m[0x8140] = (1,) # GL_PIXEL_TILE_WIDTH_SGIX
_m[0x8338] = (1,)#TODO Review http://www.opengl.org/registry/specs//EXT/pixel_transform.txt # GL_PIXEL_TRANSFORM_2D_MATRIX_EXT
_m[0x8336] = (1,) # GL_PIXEL_TRANSFORM_2D_STACK_DEPTH_EXT
_m[0x88EF] = (1,) # GL_PIXEL_UNPACK_BUFFER_BINDING
_m[0x88EF] = (1,) # GL_PIXEL_UNPACK_BUFFER_BINDING_ARB
_m[0x88EF] = (1,) # GL_PIXEL_UNPACK_BUFFER_BINDING_EXT
_m[0x87F3] = (1,) # GL_PN_TRIANGLES_NORMAL_MODE_ATI
_m[0x87F2] = (1,) # GL_PN_TRIANGLES_POINT_MODE_ATI
_m[0x87F4] = (1,) # GL_PN_TRIANGLES_TESSELATION_LEVEL_ATI
_m[0x8129] = (3,) # GL_POINT_DISTANCE_ATTENUATION
_m[0x8129] = (3,) # GL_POINT_DISTANCE_ATTENUATION_ARB
_m[0x8128] = (1,) # GL_POINT_FADE_THRESHOLD_SIZE
_m[0x8128] = (1,) # GL_POINT_FADE_THRESHOLD_SIZE_ARB
_m[0x8128] = (1,) # GL_POINT_FADE_THRESHOLD_SIZE_SGIS
_m[0x0B11] = (1,) # GL_POINT_SIZE
_m[0x0B13] = (1,) # GL_POINT_SIZE_GRANULARITY
_m[0x8127] = (1,) # GL_POINT_SIZE_MAX
_m[0x8127] = (1,) # GL_POINT_SIZE_MAX_ARB
_m[0x8127] = (1,) # GL_POINT_SIZE_MAX_SGIS
_m[0x8126] = (1,) # GL_POINT_SIZE_MIN
_m[0x8126] = (1,) # GL_POINT_SIZE_MIN_ARB
_m[0x8126] = (1,) # GL_POINT_SIZE_MIN_SGIS
_m[0x0B12] = (2,) # GL_POINT_SIZE_RANGE
_m[0x0B10] = (1,) # GL_POINT_SMOOTH
_m[0x0C51] = (1,) # GL_POINT_SMOOTH_HINT
_m[0x8861] = (1,) # GL_POINT_SPRITE
_m[0x8861] = (1,) # GL_POINT_SPRITE_ARB
_m[0x8CA0] = (1,) # GL_POINT_SPRITE_COORD_ORIGIN
_m[0x8861] = (1,) # GL_POINT_SPRITE_NV
_m[0x8863] = (1,) # GL_POINT_SPRITE_R_MODE_NV
_m[0x0B40] = (2,) # GL_POLYGON_MODE
_m[0x8039] = (1,) # GL_POLYGON_OFFSET_BIAS_EXT
_m[0x8037] = (1,) # GL_POLYGON_OFFSET_EXT
_m[0x8038] = (1,) # GL_POLYGON_OFFSET_FACTOR
_m[0x8038] = (1,) # GL_POLYGON_OFFSET_FACTOR_EXT
_m[0x8037] = (1,) # GL_POLYGON_OFFSET_FILL
_m[0x2A02] = (1,) # GL_POLYGON_OFFSET_LINE
_m[0x2A01] = (1,) # GL_POLYGON_OFFSET_POINT
_m[0x2A00] = (1,) # GL_POLYGON_OFFSET_UNITS
_m[0x0B41] = (1,) # GL_POLYGON_SMOOTH
_m[0x0C53] = (1,) # GL_POLYGON_SMOOTH_HINT
_m[0x0B42] = (1,) # GL_POLYGON_STIPPLE
_m[0x1203] = (4,) # GL_POSITION
_m[0x80BB] = (1,) # GL_POST_COLOR_MATRIX_ALPHA_BIAS
_m[0x80BB] = (1,) # GL_POST_COLOR_MATRIX_ALPHA_BIAS_SGI
_m[0x80B7] = (1,) # GL_POST_COLOR_MATRIX_ALPHA_SCALE
_m[0x80B7] = (1,) # GL_POST_COLOR_MATRIX_ALPHA_SCALE_SGI
_m[0x80BA] = (1,) # GL_POST_COLOR_MATRIX_BLUE_BIAS
_m[0x80BA] = (1,) # GL_POST_COLOR_MATRIX_BLUE_BIAS_SGI
_m[0x80B6] = (1,) # GL_POST_COLOR_MATRIX_BLUE_SCALE
_m[0x80B6] = (1,) # GL_POST_COLOR_MATRIX_BLUE_SCALE_SGI
_m[0x80D2] = (1,) # GL_POST_COLOR_MATRIX_COLOR_TABLE
_m[0x80D2] = (1,) # GL_POST_COLOR_MATRIX_COLOR_TABLE_SGI
_m[0x80B9] = (1,) # GL_POST_COLOR_MATRIX_GREEN_BIAS
_m[0x80B9] = (1,) # GL_POST_COLOR_MATRIX_GREEN_BIAS_SGI
_m[0x80B5] = (1,) # GL_POST_COLOR_MATRIX_GREEN_SCALE
_m[0x80B5] = (1,) # GL_POST_COLOR_MATRIX_GREEN_SCALE_SGI
_m[0x80B8] = (1,) # GL_POST_COLOR_MATRIX_RED_BIAS
_m[0x80B8] = (1,) # GL_POST_COLOR_MATRIX_RED_BIAS_SGI
_m[0x80B4] = (1,) # GL_POST_COLOR_MATRIX_RED_SCALE
_m[0x80B4] = (1,) # GL_POST_COLOR_MATRIX_RED_SCALE_SGI
_m[0x8023] = (1,) # GL_POST_CONVOLUTION_ALPHA_BIAS
_m[0x8023] = (1,) # GL_POST_CONVOLUTION_ALPHA_BIAS_EXT
_m[0x801F] = (1,) # GL_POST_CONVOLUTION_ALPHA_SCALE
_m[0x801F] = (1,) # GL_POST_CONVOLUTION_ALPHA_SCALE_EXT
_m[0x8022] = (1,) # GL_POST_CONVOLUTION_BLUE_BIAS
_m[0x8022] = (1,) # GL_POST_CONVOLUTION_BLUE_BIAS_EXT
_m[0x801E] = (1,) # GL_POST_CONVOLUTION_BLUE_SCALE
_m[0x801E] = (1,) # GL_POST_CONVOLUTION_BLUE_SCALE_EXT
_m[0x80D1] = (1,) # GL_POST_CONVOLUTION_COLOR_TABLE
_m[0x80D1] = (1,) # GL_POST_CONVOLUTION_COLOR_TABLE_SGI
_m[0x8021] = (1,) # GL_POST_CONVOLUTION_GREEN_BIAS
_m[0x8021] = (1,) # GL_POST_CONVOLUTION_GREEN_BIAS_EXT
_m[0x801D] = (1,) # GL_POST_CONVOLUTION_GREEN_SCALE
_m[0x801D] = (1,) # GL_POST_CONVOLUTION_GREEN_SCALE_EXT
_m[0x8020] = (1,) # GL_POST_CONVOLUTION_RED_BIAS
_m[0x8020] = (1,) # GL_POST_CONVOLUTION_RED_BIAS_EXT
_m[0x801C] = (1,) # GL_POST_CONVOLUTION_RED_SCALE
_m[0x801C] = (1,) # GL_POST_CONVOLUTION_RED_SCALE_EXT
_m[0x817B] = (1,) # GL_POST_TEXTURE_FILTER_BIAS_RANGE_SGIX
_m[0x8179] = (1,) # GL_POST_TEXTURE_FILTER_BIAS_SGIX
_m[0x817C] = (1,) # GL_POST_TEXTURE_FILTER_SCALE_RANGE_SGIX
_m[0x817A] = (1,) # GL_POST_TEXTURE_FILTER_SCALE_SGIX
_m[0x86E4] = (1,) # GL_PREVIOUS_TEXTURE_INPUT_NV
_m[0x8F9D] = (1,) # GL_PRIMITIVE_RESTART
_m[0x8D69] = (1,) # GL_PRIMITIVE_RESTART_FIXED_INDEX
_m[0x8F9E] = (1,) # GL_PRIMITIVE_RESTART_INDEX
_m[0x8559] = (1,) # GL_PRIMITIVE_RESTART_INDEX_NV
_m[0x8558] = (1,) # GL_PRIMITIVE_RESTART_NV
_m[0x88B0] = (1,) # GL_PROGRAM_ADDRESS_REGISTERS_ARB
_m[0x8805] = (1,) # GL_PROGRAM_ALU_INSTRUCTIONS_ARB
_m[0x88AC] = (1,) # GL_PROGRAM_ATTRIBS_ARB
_m[0x8906] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/gpu_program4.txt # GL_PROGRAM_ATTRIB_COMPONENTS_NV
_m[0x87FF] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/get_program_binary.txt # GL_PROGRAM_BINARY_FORMATS
_m[0x8741] = (1,) # GL_PROGRAM_BINARY_LENGTH
_m[0x8677] = (1,) # GL_PROGRAM_BINDING_ARB
_m[0x864B] = (1,) # GL_PROGRAM_ERROR_POSITION_ARB
_m[0x864B] = (1,) # GL_PROGRAM_ERROR_POSITION_NV
_m[0x8874] = (1,) # GL_PROGRAM_ERROR_STRING_ARB
_m[0x8876] = (1,) # GL_PROGRAM_FORMAT_ARB
_m[0x88A0] = (1,) # GL_PROGRAM_INSTRUCTIONS_ARB
_m[0x8627] = (1,) # GL_PROGRAM_LENGTH_ARB
_m[0x8627] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/vertex_program.txt # GL_PROGRAM_LENGTH_NV
_m[0x8E2D] = (1,)#TODO Review http://www.opengl.org/registry/specs//EXT/direct_state_access.txt # GL_PROGRAM_MATRIX_EXT
_m[0x8E2F] = (1,)#TODO Review http://www.opengl.org/registry/specs//EXT/direct_state_access.txt # GL_PROGRAM_MATRIX_STACK_DEPTH_EXT
_m[0x88B2] = (1,) # GL_PROGRAM_NATIVE_ADDRESS_REGISTERS_ARB
_m[0x8808] = (1,) # GL_PROGRAM_NATIVE_ALU_INSTRUCTIONS_ARB
_m[0x88AE] = (1,) # GL_PROGRAM_NATIVE_ATTRIBS_ARB
_m[0x88A2] = (1,) # GL_PROGRAM_NATIVE_INSTRUCTIONS_ARB
_m[0x88AA] = (1,) # GL_PROGRAM_NATIVE_PARAMETERS_ARB
_m[0x88A6] = (1,) # GL_PROGRAM_NATIVE_TEMPORARIES_ARB
_m[0x880A] = (1,) # GL_PROGRAM_NATIVE_TEX_INDIRECTIONS_ARB
_m[0x8809] = (1,) # GL_PROGRAM_NATIVE_TEX_INSTRUCTIONS_ARB
_m[0x8B40] = (1,) # GL_PROGRAM_OBJECT_ARB
_m[0x88A8] = (1,) # GL_PROGRAM_PARAMETERS_ARB
_m[0x8644] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/vertex_program.txt # GL_PROGRAM_PARAMETER_NV
_m[0x825A] = (1,) # GL_PROGRAM_PIPELINE_BINDING
_m[0x8642] = (1,) # GL_PROGRAM_POINT_SIZE
_m[0x8642] = (1,) # GL_PROGRAM_POINT_SIZE_ARB
_m[0x8642] = (1,) # GL_PROGRAM_POINT_SIZE_EXT
_m[0x8647] = (1,) # GL_PROGRAM_RESIDENT_NV
_m[0x8907] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/gpu_program4.txt # GL_PROGRAM_RESULT_COMPONENTS_NV
_m[0x8628] = (1,) # GL_PROGRAM_STRING_ARB
_m[0x8628] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/vertex_program.txt # GL_PROGRAM_STRING_NV
_m[0x8646] = (1,) # GL_PROGRAM_TARGET_NV
_m[0x88A4] = (1,) # GL_PROGRAM_TEMPORARIES_ARB
_m[0x8807] = (1,) # GL_PROGRAM_TEX_INDIRECTIONS_ARB
_m[0x8806] = (1,) # GL_PROGRAM_TEX_INSTRUCTIONS_ARB
_m[0x88B6] = (1,) # GL_PROGRAM_UNDER_NATIVE_LIMITS_ARB
_m[0x0BA7] = (4, 4) # GL_PROJECTION_MATRIX
_m[0x0BA4] = (1,) # GL_PROJECTION_STACK_DEPTH
_m[0x8E4F] = (1,) # GL_PROVOKING_VERTEX
_m[0x8E4F] = (1,) # GL_PROVOKING_VERTEX_EXT
_m[0x1209] = (1,) # GL_QUADRATIC_ATTENUATION
_m[0x8E4C] = (1,) # GL_QUADS_FOLLOW_PROVOKING_VERTEX_CONVENTION
_m[0x8E4C] = (1,) # GL_QUADS_FOLLOW_PROVOKING_VERTEX_CONVENTION_EXT
_m[0x9193] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/query_buffer_object.txt # GL_QUERY_BUFFER_BINDING
_m[0x9193] = (1,) # GL_QUERY_BUFFER_BINDING_AMD
_m[0x8864] = (1,) # GL_QUERY_COUNTER_BITS
_m[0x8864] = (1,) # GL_QUERY_COUNTER_BITS_ARB
_m[0x8866] = (1,) # GL_QUERY_RESULT
_m[0x8867] = (1,) # GL_QUERY_RESULT_AVAILABLE
_m[0x9194] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/query_buffer_object.txt # GL_QUERY_RESULT_NO_WAIT
_m[0x82EA] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/direct_state_access.txt # GL_QUERY_TARGET
_m[0x8C89] = (1,) # GL_RASTERIZER_DISCARD
_m[0x19262] = (1,) # GL_RASTER_POSITION_UNCLIPPED_IBM
_m[0x0C02] = (1,) # GL_READ_BUFFER
_m[0x0C02] = (1,) # GL_READ_BUFFER_EXT
_m[0x0C02] = (1,) # GL_READ_BUFFER_NV
_m[0x8CA8] = (1,) # GL_READ_FRAMEBUFFER
_m[0x8CAA] = (1,) # GL_READ_FRAMEBUFFER_BINDING
_m[0x828C] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_READ_PIXELS
_m[0x828D] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_READ_PIXELS_FORMAT
_m[0x828E] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_READ_PIXELS_TYPE
_m[0x887B] = (1,) # GL_READ_PIXEL_DATA_RANGE_LENGTH_NV
_m[0x887D] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/pixel_data_range.txt # GL_READ_PIXEL_DATA_RANGE_POINTER_NV
_m[0x0D15] = (1,) # GL_RED_BIAS
_m[0x0D52] = (1,) # GL_RED_BITS
_m[0x8564] = (1,) # GL_RED_MAX_CLAMP_INGR
_m[0x8560] = (1,) # GL_RED_MIN_CLAMP_INGR
_m[0x0D14] = (1,) # GL_RED_SCALE
_m[0x930B] = (1,) # GL_REFERENCED_BY_COMPUTE_SHADER
_m[0x930A] = (1,) # GL_REFERENCED_BY_FRAGMENT_SHADER
_m[0x9309] = (1,) # GL_REFERENCED_BY_GEOMETRY_SHADER
_m[0x9307] = (1,) # GL_REFERENCED_BY_TESS_CONTROL_SHADER
_m[0x9308] = (1,) # GL_REFERENCED_BY_TESS_EVALUATION_SHADER
_m[0x9306] = (1,) # GL_REFERENCED_BY_VERTEX_SHADER
_m[0x817E] = (4,) # GL_REFERENCE_PLANE_EQUATION_SGIX
_m[0x817D] = (1,) # GL_REFERENCE_PLANE_SGIX
_m[0x8522] = (1,) # GL_REGISTER_COMBINERS_NV
_m[0x8D53] = (1,) # GL_RENDERBUFFER_ALPHA_SIZE
_m[0x8CA7] = (1,) # GL_RENDERBUFFER_BINDING
_m[0x8CA7] = (1,) # GL_RENDERBUFFER_BINDING_EXT
_m[0x8D52] = (1,) # GL_RENDERBUFFER_BLUE_SIZE
_m[0x8E10] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/framebuffer_multisample_coverage.txt # GL_RENDERBUFFER_COLOR_SAMPLES_NV
_m[0x8CAB] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/framebuffer_multisample_coverage.txt # GL_RENDERBUFFER_COVERAGE_SAMPLES_NV
_m[0x8D54] = (1,) # GL_RENDERBUFFER_DEPTH_SIZE
_m[0x87FD] = (1,) # GL_RENDERBUFFER_FREE_MEMORY_ATI
_m[0x8D51] = (1,) # GL_RENDERBUFFER_GREEN_SIZE
_m[0x8D43] = (1,) # GL_RENDERBUFFER_HEIGHT
_m[0x8D44] = (1,) # GL_RENDERBUFFER_INTERNAL_FORMAT
_m[0x8D50] = (1,) # GL_RENDERBUFFER_RED_SIZE
_m[0x8CAB] = (1,) # GL_RENDERBUFFER_SAMPLES
_m[0x8D55] = (1,) # GL_RENDERBUFFER_STENCIL_SIZE
_m[0x8D42] = (1,) # GL_RENDERBUFFER_WIDTH
_m[0x1F01] = (1,) # GL_RENDERER
_m[0x0C40] = (1,) # GL_RENDER_MODE
_m[0x85C2] = (1,) # GL_REPLACEMENT_CODE_ARRAY_STRIDE_SUN
_m[0x85C1] = (1,) # GL_REPLACEMENT_CODE_ARRAY_TYPE_SUN
_m[0x81D8] = (1,) # GL_REPLACEMENT_CODE_SUN
_m[0x803A] = (1,) # GL_RESCALE_NORMAL
_m[0x803A] = (1,) # GL_RESCALE_NORMAL_EXT
_m[0x8256] = (1,)#TODO Review http://www.opengl.org/registry/specs//KHR/robustness.txt # GL_RESET_NOTIFICATION_STRATEGY
_m[0x8256] = (1,) # GL_RESET_NOTIFICATION_STRATEGY_ARB
_m[0x8820] = (1,) # GL_RGBA_FLOAT_MODE_ARB
_m[0x8820] = (1,) # GL_RGBA_FLOAT_MODE_ATI
_m[0x8D9E] = (1,) # GL_RGBA_INTEGER_MODE_EXT
_m[0x0C31] = (1,) # GL_RGBA_MODE
_m[0x8C3C] = (1,) # GL_RGBA_SIGNED_COMPONENTS_EXT
_m[0x86D9] = (1,) # GL_RGBA_UNSIGNED_DOT_PRODUCT_MAPPING_NV
_m[0x8573] = (1,) # GL_RGB_SCALE
_m[0x8919] = (1,) # GL_SAMPLER_BINDING
_m[0x80A9] = (1,) # GL_SAMPLES
_m[0x86B4] = (1,) # GL_SAMPLES_3DFX
_m[0x80A9] = (1,) # GL_SAMPLES_ARB
_m[0x80A9] = (1,) # GL_SAMPLES_SGIS
_m[0x809E] = (1,) # GL_SAMPLE_ALPHA_TO_COVERAGE
_m[0x809E] = (1,) # GL_SAMPLE_ALPHA_TO_COVERAGE_ARB
_m[0x809E] = (1,) # GL_SAMPLE_ALPHA_TO_MASK_EXT
_m[0x809E] = (1,) # GL_SAMPLE_ALPHA_TO_MASK_SGIS
_m[0x809F] = (1,) # GL_SAMPLE_ALPHA_TO_ONE
_m[0x809F] = (1,) # GL_SAMPLE_ALPHA_TO_ONE_ARB
_m[0x809F] = (1,) # GL_SAMPLE_ALPHA_TO_ONE_EXT
_m[0x809F] = (1,) # GL_SAMPLE_ALPHA_TO_ONE_SGIS
_m[0x80A8] = (1,) # GL_SAMPLE_BUFFERS
_m[0x86B3] = (1,) # GL_SAMPLE_BUFFERS_3DFX
_m[0x80A8] = (1,) # GL_SAMPLE_BUFFERS_ARB
_m[0x80A8] = (1,) # GL_SAMPLE_BUFFERS_SGIS
_m[0x80A0] = (1,) # GL_SAMPLE_COVERAGE
_m[0x80A0] = (1,) # GL_SAMPLE_COVERAGE_ARB
_m[0x80AB] = (1,) # GL_SAMPLE_COVERAGE_INVERT
_m[0x80AB] = (1,) # GL_SAMPLE_COVERAGE_INVERT_ARB
_m[0x80AA] = (1,) # GL_SAMPLE_COVERAGE_VALUE
_m[0x80AA] = (1,) # GL_SAMPLE_COVERAGE_VALUE_ARB
_m[0x8E51] = (1,) # GL_SAMPLE_MASK
_m[0x80A0] = (1,) # GL_SAMPLE_MASK_EXT
_m[0x80AB] = (1,) # GL_SAMPLE_MASK_INVERT_SGIS
_m[0x8E51] = (1,) # GL_SAMPLE_MASK_NV
_m[0x80A0] = (1,) # GL_SAMPLE_MASK_SGIS
_m[0x8E52] = (1,) # GL_SAMPLE_MASK_VALUE
_m[0x80AA] = (1,) # GL_SAMPLE_MASK_VALUE_SGIS
_m[0x80AC] = (1,) # GL_SAMPLE_PATTERN_EXT
_m[0x80AC] = (1,) # GL_SAMPLE_PATTERN_SGIS
_m[0x8E50] = (1,) # GL_SAMPLE_POSITION
_m[0x8C36] = (1,) # GL_SAMPLE_SHADING_ARB
_m[0x0C10] = (4,) # GL_SCISSOR_BOX
_m[0x0C11] = (1,) # GL_SCISSOR_TEST
_m[0x845E] = (1,) # GL_SECONDARY_COLOR_ARRAY
_m[0x889C] = (1,) # GL_SECONDARY_COLOR_ARRAY_BUFFER_BINDING
_m[0x889C] = (1,) # GL_SECONDARY_COLOR_ARRAY_BUFFER_BINDING_ARB
_m[0x8F31] = (1,) # GL_SECONDARY_COLOR_ARRAY_LENGTH_NV
_m[0x845D] = (1,)#TODO Review http://www.opengl.org/registry/specs//EXT/secondary_color.txt # GL_SECONDARY_COLOR_ARRAY_POINTER_EXT
_m[0x845A] = (1,) # GL_SECONDARY_COLOR_ARRAY_SIZE
_m[0x845A] = (1,) # GL_SECONDARY_COLOR_ARRAY_SIZE_EXT
_m[0x845C] = (1,) # GL_SECONDARY_COLOR_ARRAY_STRIDE
_m[0x845C] = (1,) # GL_SECONDARY_COLOR_ARRAY_STRIDE_EXT
_m[0x845B] = (1,) # GL_SECONDARY_COLOR_ARRAY_TYPE
_m[0x845B] = (1,) # GL_SECONDARY_COLOR_ARRAY_TYPE_EXT
_m[0x0DF3] = (1,) # GL_SELECTION_BUFFER_POINTER
_m[0x0DF4] = (1,) # GL_SELECTION_BUFFER_SIZE
_m[0x8012] = (1,) # GL_SEPARABLE_2D
_m[0x8012] = (1,) # GL_SEPARABLE_2D_EXT
_m[0x8DF8] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/ES2_compatibility.txt # GL_SHADER_BINARY_FORMATS
_m[0x8DFA] = (1,) # GL_SHADER_COMPILER
_m[0x82A6] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_SHADER_IMAGE_ATOMIC
_m[0x82A4] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_SHADER_IMAGE_LOAD
_m[0x82A5] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_SHADER_IMAGE_STORE
_m[0x86DF] = (1,) # GL_SHADER_OPERATION_NV
_m[0x8B88] = (1,) # GL_SHADER_SOURCE_LENGTH
_m[0x90D2] = (1,) # GL_SHADER_STORAGE_BUFFER
_m[0x90D3] = (1,) # GL_SHADER_STORAGE_BUFFER_BINDING
_m[0x90DF] = (1,) # GL_SHADER_STORAGE_BUFFER_OFFSET_ALIGNMENT
_m[0x90D5] = (1,) # GL_SHADER_STORAGE_BUFFER_SIZE
_m[0x90D4] = (1,) # GL_SHADER_STORAGE_BUFFER_START
_m[0x8B4F] = (1,) # GL_SHADER_TYPE
_m[0x0B54] = (1,) # GL_SHADE_MODEL
_m[0x8B8C] = (1,) # GL_SHADING_LANGUAGE_VERSION
_m[0x1601] = (1,) # GL_SHININESS
_m[0x82AC] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_SIMULTANEOUS_TEXTURE_AND_DEPTH_TEST
_m[0x82AE] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_SIMULTANEOUS_TEXTURE_AND_DEPTH_WRITE
_m[0x82AD] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_SIMULTANEOUS_TEXTURE_AND_STENCIL_TEST
_m[0x82AF] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_SIMULTANEOUS_TEXTURE_AND_STENCIL_WRITE
_m[0x0B23] = (1,) # GL_SMOOTH_LINE_WIDTH_GRANULARITY
_m[0x0B22] = (2,) # GL_SMOOTH_LINE_WIDTH_RANGE
_m[0x0B13] = (1,) # GL_SMOOTH_POINT_SIZE_GRANULARITY
_m[0x0B12] = (2,) # GL_SMOOTH_POINT_SIZE_RANGE
_m[0x933B] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/shader_thread_group.txt # GL_SM_COUNT_NV
_m[0x858B] = (1,) # GL_SOURCE3_ALPHA_NV
_m[0x8583] = (1,) # GL_SOURCE3_RGB_NV
_m[0x82F8] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/sparse_buffer.txt # GL_SPARSE_BUFFER_PAGE_SIZE_ARB
_m[0x91A9] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/sparse_texture.txt # GL_SPARSE_TEXTURE_FULL_ARRAY_CUBE_MIPMAPS_ARB
_m[0x1202] = (4,) # GL_SPECULAR
_m[0x1206] = (1,) # GL_SPOT_CUTOFF
_m[0x1204] = (3,) # GL_SPOT_DIRECTION
_m[0x1205] = (1,) # GL_SPOT_EXPONENT
_m[0x814A] = (3,) # GL_SPRITE_AXIS_SGIX
_m[0x8149] = (1,) # GL_SPRITE_MODE_SGIX
_m[0x8148] = (1,) # GL_SPRITE_SGIX
_m[0x814B] = (3,) # GL_SPRITE_TRANSLATION_SGIX
_m[0x8588] = (1,) # GL_SRC0_ALPHA
_m[0x8580] = (1,) # GL_SRC0_RGB
_m[0x8589] = (1,) # GL_SRC1_ALPHA
_m[0x8581] = (1,) # GL_SRC1_RGB
_m[0x858A] = (1,) # GL_SRC2_ALPHA
_m[0x8582] = (1,) # GL_SRC2_RGB
_m[0x8299] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_SRGB_DECODE_ARB
_m[0x8297] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_SRGB_READ
_m[0x8298] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_SRGB_WRITE
_m[0x8801] = (1,) # GL_STENCIL_BACK_FAIL
_m[0x8801] = (1,) # GL_STENCIL_BACK_FAIL_ATI
_m[0x8800] = (1,) # GL_STENCIL_BACK_FUNC
_m[0x8800] = (1,) # GL_STENCIL_BACK_FUNC_ATI
_m[0x874D] = (1,) # GL_STENCIL_BACK_OP_VALUE_AMD
_m[0x8802] = (1,) # GL_STENCIL_BACK_PASS_DEPTH_FAIL
_m[0x8802] = (1,) # GL_STENCIL_BACK_PASS_DEPTH_FAIL_ATI
_m[0x8803] = (1,) # GL_STENCIL_BACK_PASS_DEPTH_PASS
_m[0x8803] = (1,) # GL_STENCIL_BACK_PASS_DEPTH_PASS_ATI
_m[0x8CA3] = (1,) # GL_STENCIL_BACK_REF
_m[0x8CA4] = (1,) # GL_STENCIL_BACK_VALUE_MASK
_m[0x8CA5] = (1,) # GL_STENCIL_BACK_WRITEMASK
_m[0x0D57] = (1,) # GL_STENCIL_BITS
_m[0x88F3] = (1,) # GL_STENCIL_CLEAR_TAG_VALUE_EXT
_m[0x0B91] = (1,) # GL_STENCIL_CLEAR_VALUE
_m[0x8285] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_STENCIL_COMPONENTS
_m[0x0B94] = (1,) # GL_STENCIL_FAIL
_m[0x0B92] = (1,) # GL_STENCIL_FUNC
_m[0x874C] = (1,) # GL_STENCIL_OP_VALUE_AMD
_m[0x0B95] = (1,) # GL_STENCIL_PASS_DEPTH_FAIL
_m[0x0B96] = (1,) # GL_STENCIL_PASS_DEPTH_PASS
_m[0x0B97] = (1,) # GL_STENCIL_REF
_m[0x8288] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_STENCIL_RENDERABLE
_m[0x88F2] = (1,) # GL_STENCIL_TAG_BITS_EXT
_m[0x0B90] = (1,) # GL_STENCIL_TEST
_m[0x8910] = (1,) # GL_STENCIL_TEST_TWO_SIDE_EXT
_m[0x0B93] = (1,) # GL_STENCIL_VALUE_MASK
_m[0x0B98] = (1,) # GL_STENCIL_WRITEMASK
_m[0x0C33] = (1,) # GL_STEREO
_m[0x0D50] = (1,) # GL_SUBPIXEL_BITS
_m[0x883F] = (1,)#TODO Review http://www.opengl.org/registry/specs//AMD/sample_positions.txt # GL_SUBSAMPLE_DISTANCE_AMD
_m[0x9113] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/sync.txt # GL_SYNC_CONDITION
_m[0x9115] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/sync.txt # GL_SYNC_FLAGS
_m[0x9114] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/sync.txt # GL_SYNC_STATUS
_m[0x8439] = (1,) # GL_TANGENT_ARRAY_EXT
_m[0x8442] = (1,) # GL_TANGENT_ARRAY_POINTER_EXT
_m[0x843F] = (1,) # GL_TANGENT_ARRAY_STRIDE_EXT
_m[0x843E] = (1,) # GL_TANGENT_ARRAY_TYPE_EXT
_m[0x9004] = (1,) # GL_TESSELLATION_MODE_AMD
_m[0x8E75] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/tessellation_shader.txt # GL_TESS_CONTROL_OUTPUT_VERTICES
_m[0x891E] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/tessellation_program5.txt # GL_TESS_CONTROL_PROGRAM_NV
_m[0x8E88] = (1,) # GL_TESS_CONTROL_SHADER
_m[0x829C] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_TESS_CONTROL_TEXTURE
_m[0x891F] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/tessellation_program5.txt # GL_TESS_EVALUATION_PROGRAM_NV
_m[0x8E87] = (1,) # GL_TESS_EVALUATION_SHADER
_m[0x829D] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_TESS_EVALUATION_TEXTURE
_m[0x8E76] = (1,) # GL_TESS_GEN_MODE
_m[0x8E79] = (1,) # GL_TESS_GEN_POINT_MODE
_m[0x8E77] = (1,) # GL_TESS_GEN_SPACING
_m[0x8E78] = (1,) # GL_TESS_GEN_VERTEX_ORDER
_m[0x0DE0] = (1,) # GL_TEXTURE_1D
_m[0x8068] = (1,) # GL_TEXTURE_1D_BINDING_EXT
_m[0x875D] = (1,) # GL_TEXTURE_1D_STACK_BINDING_MESAX
_m[0x8759] = (1,) # GL_TEXTURE_1D_STACK_MESAX
_m[0x0DE1] = (1,) # GL_TEXTURE_2D
_m[0x8069] = (1,) # GL_TEXTURE_2D_BINDING_EXT
_m[0x875E] = (1,) # GL_TEXTURE_2D_STACK_BINDING_MESAX
_m[0x875A] = (1,) # GL_TEXTURE_2D_STACK_MESAX
_m[0x806F] = (1,) # GL_TEXTURE_3D
_m[0x806A] = (1,) # GL_TEXTURE_3D_BINDING_EXT
_m[0x806F] = (1,) # GL_TEXTURE_3D_EXT
_m[0x806F] = (1,) # GL_TEXTURE_3D_OES
_m[0x814F] = (1,) # GL_TEXTURE_4D_BINDING_SGIS
_m[0x8134] = (1,) # GL_TEXTURE_4D_SGIS
_m[0x805F] = (1,) # GL_TEXTURE_ALPHA_SIZE
_m[0x8C13] = (1,) # GL_TEXTURE_ALPHA_TYPE
_m[0x834F] = (1,) # GL_TEXTURE_APPLICATION_MODE_EXT
_m[0x813C] = (1,) # GL_TEXTURE_BASE_LEVEL
_m[0x813C] = (1,) # GL_TEXTURE_BASE_LEVEL_SGIS
_m[0x8068] = (1,) # GL_TEXTURE_BINDING_1D
_m[0x8C1C] = (1,) # GL_TEXTURE_BINDING_1D_ARRAY
_m[0x8C1C] = (1,) # GL_TEXTURE_BINDING_1D_ARRAY_EXT
_m[0x8069] = (1,) # GL_TEXTURE_BINDING_2D
_m[0x8C1D] = (1,) # GL_TEXTURE_BINDING_2D_ARRAY
_m[0x8C1D] = (1,) # GL_TEXTURE_BINDING_2D_ARRAY_EXT
_m[0x9104] = (1,) # GL_TEXTURE_BINDING_2D_MULTISAMPLE
_m[0x9105] = (1,) # GL_TEXTURE_BINDING_2D_MULTISAMPLE_ARRAY
_m[0x806A] = (1,) # GL_TEXTURE_BINDING_3D
_m[0x8C2C] = (1,) # GL_TEXTURE_BINDING_BUFFER
_m[0x8C2C] = (1,) # GL_TEXTURE_BINDING_BUFFER_ARB
_m[0x8C2C] = (1,) # GL_TEXTURE_BINDING_BUFFER_EXT
_m[0x8514] = (1,) # GL_TEXTURE_BINDING_CUBE_MAP
_m[0x8514] = (1,) # GL_TEXTURE_BINDING_CUBE_MAP_ARB
_m[0x900A] = (1,) # GL_TEXTURE_BINDING_CUBE_MAP_ARRAY
_m[0x900A] = (1,) # GL_TEXTURE_BINDING_CUBE_MAP_ARRAY_ARB
_m[0x84F6] = (1,) # GL_TEXTURE_BINDING_RECTANGLE
_m[0x84F6] = (1,) # GL_TEXTURE_BINDING_RECTANGLE_ARB
_m[0x84F6] = (1,) # GL_TEXTURE_BINDING_RECTANGLE_NV
_m[0x8E53] = (1,) # GL_TEXTURE_BINDING_RENDERBUFFER_NV
_m[0x805E] = (1,) # GL_TEXTURE_BLUE_SIZE
_m[0x8C12] = (1,) # GL_TEXTURE_BLUE_TYPE
_m[0x1005] = (1,) # GL_TEXTURE_BORDER
_m[0x1004] = (4,) # GL_TEXTURE_BORDER_COLOR
_m[0x1004] = (4,) # GL_TEXTURE_BORDER_COLOR_NV
_m[0x8C2A] = (1,) # GL_TEXTURE_BUFFER
_m[0x8C2A] = (1,) # GL_TEXTURE_BUFFER_ARB
_m[0x8C2D] = (1,) # GL_TEXTURE_BUFFER_DATA_STORE_BINDING
_m[0x8C2D] = (1,) # GL_TEXTURE_BUFFER_DATA_STORE_BINDING_ARB
_m[0x8C2D] = (1,) # GL_TEXTURE_BUFFER_DATA_STORE_BINDING_EXT
_m[0x8C2A] = (1,) # GL_TEXTURE_BUFFER_EXT
_m[0x8C2E] = (1,) # GL_TEXTURE_BUFFER_FORMAT_ARB
_m[0x8C2E] = (1,) # GL_TEXTURE_BUFFER_FORMAT_EXT
_m[0x919D] = (1,) # GL_TEXTURE_BUFFER_OFFSET
_m[0x919F] = (1,) # GL_TEXTURE_BUFFER_OFFSET_ALIGNMENT
_m[0x919E] = (1,) # GL_TEXTURE_BUFFER_SIZE
_m[0x8171] = (2,) # GL_TEXTURE_CLIPMAP_CENTER_SGIX
_m[0x8176] = (1,) # GL_TEXTURE_CLIPMAP_DEPTH_SGIX
_m[0x8172] = (1,) # GL_TEXTURE_CLIPMAP_FRAME_SGIX
_m[0x8173] = (2,) # GL_TEXTURE_CLIPMAP_OFFSET_SGIX
_m[0x8174] = (3,) # GL_TEXTURE_CLIPMAP_VIRTUAL_DEPTH_SGIX
_m[0x9046] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/texture_multisample.txt # GL_TEXTURE_COLOR_SAMPLES_NV
_m[0x80BC] = (1,) # GL_TEXTURE_COLOR_TABLE_SGI
_m[0x81EF] = (4,) # GL_TEXTURE_COLOR_WRITEMASK_SGIS
_m[0x80BF] = (1,) # GL_TEXTURE_COMPARE_FAIL_VALUE_ARB
_m[0x884D] = (1,) # GL_TEXTURE_COMPARE_FUNC
_m[0x884C] = (1,) # GL_TEXTURE_COMPARE_MODE
_m[0x819B] = (1,) # GL_TEXTURE_COMPARE_OPERATOR_SGIX
_m[0x819A] = (1,) # GL_TEXTURE_COMPARE_SGIX
_m[0x86A1] = (1,) # GL_TEXTURE_COMPRESSED
_m[0x82B2] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_TEXTURE_COMPRESSED_BLOCK_HEIGHT
_m[0x82B3] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_TEXTURE_COMPRESSED_BLOCK_SIZE
_m[0x82B1] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_TEXTURE_COMPRESSED_BLOCK_WIDTH
_m[0x86A0] = (1,) # GL_TEXTURE_COMPRESSED_IMAGE_SIZE
_m[0x84EF] = (1,) # GL_TEXTURE_COMPRESSION_HINT
_m[0x84EF] = (1,) # GL_TEXTURE_COMPRESSION_HINT_ARB
_m[0x8078] = (1,) # GL_TEXTURE_COORD_ARRAY
_m[0x889A] = (1,) # GL_TEXTURE_COORD_ARRAY_BUFFER_BINDING
_m[0x889A] = (1,) # GL_TEXTURE_COORD_ARRAY_BUFFER_BINDING_ARB
_m[0x808B] = (1,) # GL_TEXTURE_COORD_ARRAY_COUNT_EXT
_m[0x8078] = (1,) # GL_TEXTURE_COORD_ARRAY_EXT
_m[0x83F8] = (1,)#TODO Review http://www.opengl.org/registry/specs//INTEL/parallel_arrays.txt # GL_TEXTURE_COORD_ARRAY_PARALLEL_POINTERS_INTEL
_m[0x8092] = (1,) # GL_TEXTURE_COORD_ARRAY_POINTER
_m[0x8088] = (1,) # GL_TEXTURE_COORD_ARRAY_SIZE
_m[0x8088] = (1,) # GL_TEXTURE_COORD_ARRAY_SIZE_EXT
_m[0x808A] = (1,) # GL_TEXTURE_COORD_ARRAY_STRIDE
_m[0x808A] = (1,) # GL_TEXTURE_COORD_ARRAY_STRIDE_EXT
_m[0x8089] = (1,) # GL_TEXTURE_COORD_ARRAY_TYPE
_m[0x8089] = (1,) # GL_TEXTURE_COORD_ARRAY_TYPE_EXT
_m[0x9045] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/texture_multisample.txt # GL_TEXTURE_COVERAGE_SAMPLES_NV
_m[0x8B9D] = (4,) # GL_TEXTURE_CROP_RECT_OES
_m[0x8513] = (1,) # GL_TEXTURE_CUBE_MAP
_m[0x8513] = (1,) # GL_TEXTURE_CUBE_MAP_ARB
_m[0x9009] = (1,) # GL_TEXTURE_CUBE_MAP_ARRAY
_m[0x884F] = (1,) # GL_TEXTURE_CUBE_MAP_SEAMLESS
_m[0x8071] = (1,) # GL_TEXTURE_DEPTH
_m[0x8071] = (1,) # GL_TEXTURE_DEPTH_EXT
_m[0x884A] = (1,) # GL_TEXTURE_DEPTH_SIZE
_m[0x8C16] = (1,) # GL_TEXTURE_DEPTH_TYPE
_m[0x871D] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/texture_shader.txt # GL_TEXTURE_DS_SIZE_NV
_m[0x871E] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/texture_shader.txt # GL_TEXTURE_DT_SIZE_NV
_m[0x2201] = (4,) # GL_TEXTURE_ENV_COLOR
_m[0x2200] = (1,) # GL_TEXTURE_ENV_MODE
_m[0x9107] = (1,) # GL_TEXTURE_FIXED_SAMPLE_LOCATIONS
_m[0x888C] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/float_buffer.txt # GL_TEXTURE_FLOAT_COMPONENTS_NV
_m[0x87FC] = (1,) # GL_TEXTURE_FREE_MEMORY_ATI
_m[0x82A2] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_TEXTURE_GATHER
_m[0x82A3] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_TEXTURE_GATHER_SHADOW
_m[0x2500] = (1,) # GL_TEXTURE_GEN_MODE
_m[0x0C63] = (1,) # GL_TEXTURE_GEN_Q
_m[0x0C62] = (1,) # GL_TEXTURE_GEN_R
_m[0x0C60] = (1,) # GL_TEXTURE_GEN_S
_m[0x0C61] = (1,) # GL_TEXTURE_GEN_T
_m[0x805D] = (1,) # GL_TEXTURE_GREEN_SIZE
_m[0x8C11] = (1,) # GL_TEXTURE_GREEN_TYPE
_m[0x1001] = (1,) # GL_TEXTURE_HEIGHT
_m[0x871B] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/texture_shader.txt # GL_TEXTURE_HI_SIZE_NV
_m[0x828F] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_TEXTURE_IMAGE_FORMAT
_m[0x8290] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_TEXTURE_IMAGE_TYPE
_m[0x912F] = (1,) # GL_TEXTURE_IMMUTABLE_FORMAT
_m[0x82DF] = (1,) # GL_TEXTURE_IMMUTABLE_LEVELS
_m[0x80ED] = (1,) # GL_TEXTURE_INDEX_SIZE_EXT
_m[0x8061] = (1,) # GL_TEXTURE_INTENSITY_SIZE
_m[0x8C15] = (1,) # GL_TEXTURE_INTENSITY_TYPE
_m[0x1003] = (1,) # GL_TEXTURE_INTERNAL_FORMAT
_m[0x8350] = (1,) # GL_TEXTURE_LIGHT_EXT
_m[0x8501] = (1,) # GL_TEXTURE_LOD_BIAS
_m[0x8190] = (1,) # GL_TEXTURE_LOD_BIAS_R_SGIX
_m[0x818E] = (1,) # GL_TEXTURE_LOD_BIAS_S_SGIX
_m[0x818F] = (1,) # GL_TEXTURE_LOD_BIAS_T_SGIX
_m[0x871C] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/texture_shader.txt # GL_TEXTURE_LO_SIZE_NV
_m[0x8060] = (1,) # GL_TEXTURE_LUMINANCE_SIZE
_m[0x8C14] = (1,) # GL_TEXTURE_LUMINANCE_TYPE
_m[0x2800] = (1,) # GL_TEXTURE_MAG_FILTER
_m[0x871F] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/texture_shader.txt # GL_TEXTURE_MAG_SIZE_NV
_m[0x8351] = (1,) # GL_TEXTURE_MATERIAL_FACE_EXT
_m[0x8352] = (1,) # GL_TEXTURE_MATERIAL_PARAMETER_EXT
_m[0x0BA8] = (4, 4) # GL_TEXTURE_MATRIX
_m[0x84FE] = (1,) # GL_TEXTURE_MAX_ANISOTROPY_EXT
_m[0x836B] = (1,) # GL_TEXTURE_MAX_CLAMP_R_SGIX
_m[0x8369] = (1,) # GL_TEXTURE_MAX_CLAMP_S_SGIX
_m[0x836A] = (1,) # GL_TEXTURE_MAX_CLAMP_T_SGIX
_m[0x813D] = (1,) # GL_TEXTURE_MAX_LEVEL
_m[0x813D] = (1,) # GL_TEXTURE_MAX_LEVEL_SGIS
_m[0x813B] = (1,) # GL_TEXTURE_MAX_LOD
_m[0x813B] = (1,) # GL_TEXTURE_MAX_LOD_SGIS
_m[0x2801] = (1,) # GL_TEXTURE_MIN_FILTER
_m[0x813A] = (1,) # GL_TEXTURE_MIN_LOD
_m[0x813A] = (1,) # GL_TEXTURE_MIN_LOD_SGIS
_m[0x8066] = (1,) # GL_TEXTURE_PRIORITY
_m[0x85B8] = (1,) # GL_TEXTURE_RANGE_POINTER_APPLE
_m[0x84F5] = (1,) # GL_TEXTURE_RECTANGLE
_m[0x84F5] = (1,) # GL_TEXTURE_RECTANGLE_ARB
_m[0x84F5] = (1,) # GL_TEXTURE_RECTANGLE_NV
_m[0x805C] = (1,) # GL_TEXTURE_RED_SIZE
_m[0x8C10] = (1,) # GL_TEXTURE_RED_TYPE
_m[0x8E54] = (1,) # GL_TEXTURE_RENDERBUFFER_DATA_STORE_BINDING_NV
_m[0x8067] = (1,) # GL_TEXTURE_RESIDENT
_m[0x9106] = (1,) # GL_TEXTURE_SAMPLES
_m[0x86DE] = (1,) # GL_TEXTURE_SHADER_NV
_m[0x82A1] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_TEXTURE_SHADOW
_m[0x8C3F] = (1,)#TODO Review http://www.opengl.org/registry/specs//EXT/texture_shared_exponent.txt # GL_TEXTURE_SHARED_SIZE_EXT
_m[0x8A48] = (1,) # GL_TEXTURE_SRGB_DECODE_EXT
_m[0x0BA5] = (1,) # GL_TEXTURE_STACK_DEPTH
_m[0x88F1] = (1,) # GL_TEXTURE_STENCIL_SIZE
_m[0x85BC] = (1,) # GL_TEXTURE_STORAGE_HINT_APPLE
_m[0x8E45] = (1,) # GL_TEXTURE_SWIZZLE_A
_m[0x8E44] = (1,) # GL_TEXTURE_SWIZZLE_B
_m[0x8E43] = (1,) # GL_TEXTURE_SWIZZLE_G
_m[0x8E42] = (1,) # GL_TEXTURE_SWIZZLE_R
_m[0x8E46] = (4,) # GL_TEXTURE_SWIZZLE_RGBA
_m[0x1006] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/direct_state_access.txt # GL_TEXTURE_TARGET
_m[0x888F] = (1,) # GL_TEXTURE_UNSIGNED_REMAP_MODE_NV
_m[0x82B5] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_TEXTURE_VIEW
_m[0x82DD] = (1,) # GL_TEXTURE_VIEW_MIN_LAYER
_m[0x82DB] = (1,) # GL_TEXTURE_VIEW_MIN_LEVEL
_m[0x82DE] = (1,) # GL_TEXTURE_VIEW_NUM_LAYERS
_m[0x82DC] = (1,) # GL_TEXTURE_VIEW_NUM_LEVELS
_m[0x1000] = (1,) # GL_TEXTURE_WIDTH
_m[0x8137] = (1,) # GL_TEXTURE_WRAP_Q_SGIS
_m[0x8072] = (1,) # GL_TEXTURE_WRAP_R
_m[0x8072] = (1,) # GL_TEXTURE_WRAP_R_EXT
_m[0x2802] = (1,) # GL_TEXTURE_WRAP_S
_m[0x2803] = (1,) # GL_TEXTURE_WRAP_T
_m[0x8200] = (1,) # GL_TEXT_FRAGMENT_SHADER_ATI
_m[0x8E28] = (1,) # GL_TIMESTAMP
_m[0x930C] = (1,) # GL_TOP_LEVEL_ARRAY_SIZE
_m[0x930D] = (1,) # GL_TOP_LEVEL_ARRAY_STRIDE
_m[0x8648] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/vertex_program.txt # GL_TRACK_MATRIX_NV
_m[0x8649] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/vertex_program.txt # GL_TRACK_MATRIX_TRANSFORM_NV
_m[0x8E25] = (1,) # GL_TRANSFORM_FEEDBACK_BINDING
_m[0x8E25] = (1,) # GL_TRANSFORM_FEEDBACK_BINDING_NV
_m[0x8E24] = (1,) # GL_TRANSFORM_FEEDBACK_BUFFER_ACTIVE
_m[0x8E24] = (1,) # GL_TRANSFORM_FEEDBACK_BUFFER_ACTIVE_NV
_m[0x8C8F] = (1,) # GL_TRANSFORM_FEEDBACK_BUFFER_BINDING
_m[0x8C7F] = (1,)#TODO Review http://www.opengl.org/registry/specs//EXT/transform_feedback.txt # GL_TRANSFORM_FEEDBACK_BUFFER_MODE_EXT
_m[0x8C7F] = (1,) # GL_TRANSFORM_FEEDBACK_BUFFER_MODE_NV
_m[0x8E23] = (1,) # GL_TRANSFORM_FEEDBACK_BUFFER_PAUSED
_m[0x8E23] = (1,) # GL_TRANSFORM_FEEDBACK_BUFFER_PAUSED_NV
_m[0x8C85] = (1,) # GL_TRANSFORM_FEEDBACK_BUFFER_SIZE
_m[0x8C84] = (1,) # GL_TRANSFORM_FEEDBACK_BUFFER_START
_m[0x8C83] = (1,)#TODO Review http://www.opengl.org/registry/specs//EXT/transform_feedback.txt # GL_TRANSFORM_FEEDBACK_VARYINGS_EXT
_m[0x8C76] = (1,)#TODO Review http://www.opengl.org/registry/specs//EXT/transform_feedback.txt # GL_TRANSFORM_FEEDBACK_VARYING_MAX_LENGTH_EXT
_m[0x84E6] = (4,4) # GL_TRANSPOSE_COLOR_MATRIX
_m[0x84E6] = (4,4) # GL_TRANSPOSE_COLOR_MATRIX_ARB
_m[0x88B7] = (4, 4) # GL_TRANSPOSE_CURRENT_MATRIX_ARB
_m[0x84E3] = (4,4) # GL_TRANSPOSE_MODELVIEW_MATRIX
_m[0x84E3] = (4,4) # GL_TRANSPOSE_MODELVIEW_MATRIX_ARB
_m[0x8E2E] = (1,)#TODO Review http://www.opengl.org/registry/specs//EXT/direct_state_access.txt # GL_TRANSPOSE_PROGRAM_MATRIX_EXT
_m[0x84E4] = (4,4) # GL_TRANSPOSE_PROJECTION_MATRIX
_m[0x84E4] = (4,4) # GL_TRANSPOSE_PROJECTION_MATRIX_ARB
_m[0x84E5] = (4,4) # GL_TRANSPOSE_TEXTURE_MATRIX
_m[0x84E5] = (4,4) # GL_TRANSPOSE_TEXTURE_MATRIX_ARB
_m[0x92FA] = (1,) # GL_TYPE
_m[0x8A3C] = (1,) # GL_UNIFORM_ARRAY_STRIDE
_m[0x92DA] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/shader_atomic_counters.txt # GL_UNIFORM_ATOMIC_COUNTER_BUFFER_INDEX
_m[0x8A42] = (1,) # GL_UNIFORM_BLOCK_ACTIVE_UNIFORMS
_m[0x8A43] = (1,) # GL_UNIFORM_BLOCK_ACTIVE_UNIFORM_INDICES
_m[0x8A3F] = (1,) # GL_UNIFORM_BLOCK_BINDING
_m[0x8A40] = (1,) # GL_UNIFORM_BLOCK_DATA_SIZE
_m[0x8A3A] = (1,) # GL_UNIFORM_BLOCK_INDEX
_m[0x8A41] = (1,) # GL_UNIFORM_BLOCK_NAME_LENGTH
_m[0x90EC] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/compute_shader.txt # GL_UNIFORM_BLOCK_REFERENCED_BY_COMPUTE_SHADER
_m[0x8A46] = (1,) # GL_UNIFORM_BLOCK_REFERENCED_BY_FRAGMENT_SHADER
_m[0x8A45] = (1,) # GL_UNIFORM_BLOCK_REFERENCED_BY_GEOMETRY_SHADER
_m[0x84F0] = (1,) # GL_UNIFORM_BLOCK_REFERENCED_BY_TESS_CONTROL_SHADER
_m[0x84F1] = (1,) # GL_UNIFORM_BLOCK_REFERENCED_BY_TESS_EVALUATION_SHADER
_m[0x8A44] = (1,) # GL_UNIFORM_BLOCK_REFERENCED_BY_VERTEX_SHADER
_m[0x8A28] = (1,) # GL_UNIFORM_BUFFER_BINDING
_m[0x8DEF] = (1,) # GL_UNIFORM_BUFFER_BINDING_EXT
_m[0x8A34] = (1,) # GL_UNIFORM_BUFFER_OFFSET_ALIGNMENT
_m[0x8A2A] = (1,) # GL_UNIFORM_BUFFER_SIZE
_m[0x8A29] = (1,) # GL_UNIFORM_BUFFER_START
_m[0x8A3E] = (1,) # GL_UNIFORM_IS_ROW_MAJOR
_m[0x8A3D] = (1,) # GL_UNIFORM_MATRIX_STRIDE
_m[0x8A39] = (1,) # GL_UNIFORM_NAME_LENGTH
_m[0x8A3B] = (1,) # GL_UNIFORM_OFFSET
_m[0x8A38] = (1,) # GL_UNIFORM_SIZE
_m[0x8A37] = (1,) # GL_UNIFORM_TYPE
_m[0x0CF5] = (1,) # GL_UNPACK_ALIGNMENT
_m[0x85B2] = (1,) # GL_UNPACK_CLIENT_STORAGE_APPLE
_m[0x800F] = (1,) # GL_UNPACK_CMYK_HINT_EXT
_m[0x9129] = (1,) # GL_UNPACK_COMPRESSED_BLOCK_DEPTH
_m[0x9128] = (1,) # GL_UNPACK_COMPRESSED_BLOCK_HEIGHT
_m[0x912A] = (1,) # GL_UNPACK_COMPRESSED_BLOCK_SIZE
_m[0x9127] = (1,) # GL_UNPACK_COMPRESSED_BLOCK_WIDTH
_m[0x8133] = (1,) # GL_UNPACK_IMAGE_DEPTH_SGIS
_m[0x806E] = (1,) # GL_UNPACK_IMAGE_HEIGHT
_m[0x806E] = (1,) # GL_UNPACK_IMAGE_HEIGHT_EXT
_m[0x0CF1] = (1,) # GL_UNPACK_LSB_FIRST
_m[0x8985] = (1,) # GL_UNPACK_RESAMPLE_OML
_m[0x842F] = (1,) # GL_UNPACK_RESAMPLE_SGIX
_m[0x8A16] = (1,) # GL_UNPACK_ROW_BYTES_APPLE
_m[0x0CF2] = (1,) # GL_UNPACK_ROW_LENGTH
_m[0x806D] = (1,) # GL_UNPACK_SKIP_IMAGES
_m[0x806D] = (1,) # GL_UNPACK_SKIP_IMAGES_EXT
_m[0x0CF4] = (1,) # GL_UNPACK_SKIP_PIXELS
_m[0x0CF3] = (1,) # GL_UNPACK_SKIP_ROWS
_m[0x8132] = (1,) # GL_UNPACK_SKIP_VOLUMES_SGIS
_m[0x0CF0] = (1,) # GL_UNPACK_SWAP_BYTES
_m[0x8B83] = (1,) # GL_VALIDATE_STATUS
_m[0x87E9] = (1,)#TODO Review http://www.opengl.org/registry/specs//EXT/vertex_shader.txt # GL_VARIANT_ARRAY_POINTER_EXT
_m[0x87E7] = (1,) # GL_VARIANT_ARRAY_TYPE_EXT
_m[0x87FB] = (1,) # GL_VBO_FREE_MEMORY_ATI
_m[0x1F00] = (1,) # GL_VENDOR
_m[0x1F02] = (1,) # GL_VERSION
_m[0x8074] = (1,) # GL_VERTEX_ARRAY
_m[0x85B5] = (1,) # GL_VERTEX_ARRAY_BINDING
_m[0x85B5] = (1,) # GL_VERTEX_ARRAY_BINDING_APPLE
_m[0x8896] = (1,) # GL_VERTEX_ARRAY_BUFFER_BINDING
_m[0x8896] = (1,) # GL_VERTEX_ARRAY_BUFFER_BINDING_ARB
_m[0x807D] = (1,) # GL_VERTEX_ARRAY_COUNT_EXT
_m[0x8074] = (1,) # GL_VERTEX_ARRAY_EXT
_m[0x8F2B] = (1,) # GL_VERTEX_ARRAY_LENGTH_NV
_m[0x83F5] = (1,)#TODO Review http://www.opengl.org/registry/specs//INTEL/parallel_arrays.txt # GL_VERTEX_ARRAY_PARALLEL_POINTERS_INTEL
_m[0x808E] = (1,) # GL_VERTEX_ARRAY_POINTER
_m[0x851E] = (1,) # GL_VERTEX_ARRAY_RANGE_LENGTH_APPLE
_m[0x851E] = (1,) # GL_VERTEX_ARRAY_RANGE_LENGTH_NV
_m[0x851D] = (1,) # GL_VERTEX_ARRAY_RANGE_NV
_m[0x8521] = (1,) # GL_VERTEX_ARRAY_RANGE_POINTER_NV
_m[0x851F] = (1,) # GL_VERTEX_ARRAY_RANGE_VALID_NV
_m[0x807A] = (1,) # GL_VERTEX_ARRAY_SIZE
_m[0x807A] = (1,) # GL_VERTEX_ARRAY_SIZE_EXT
_m[0x807C] = (1,) # GL_VERTEX_ARRAY_STRIDE
_m[0x807C] = (1,) # GL_VERTEX_ARRAY_STRIDE_EXT
_m[0x807B] = (1,) # GL_VERTEX_ARRAY_TYPE
_m[0x807B] = (1,) # GL_VERTEX_ARRAY_TYPE_EXT
_m[0x8650] = (1,) # GL_VERTEX_ATTRIB_ARRAY0_NV
_m[0x865A] = (1,) # GL_VERTEX_ATTRIB_ARRAY10_NV
_m[0x865B] = (1,) # GL_VERTEX_ATTRIB_ARRAY11_NV
_m[0x865C] = (1,) # GL_VERTEX_ATTRIB_ARRAY12_NV
_m[0x865D] = (1,) # GL_VERTEX_ATTRIB_ARRAY13_NV
_m[0x865E] = (1,) # GL_VERTEX_ATTRIB_ARRAY14_NV
_m[0x865F] = (1,) # GL_VERTEX_ATTRIB_ARRAY15_NV
_m[0x8651] = (1,) # GL_VERTEX_ATTRIB_ARRAY1_NV
_m[0x8652] = (1,) # GL_VERTEX_ATTRIB_ARRAY2_NV
_m[0x8653] = (1,) # GL_VERTEX_ATTRIB_ARRAY3_NV
_m[0x8654] = (1,) # GL_VERTEX_ATTRIB_ARRAY4_NV
_m[0x8655] = (1,) # GL_VERTEX_ATTRIB_ARRAY5_NV
_m[0x8656] = (1,) # GL_VERTEX_ATTRIB_ARRAY6_NV
_m[0x8657] = (1,) # GL_VERTEX_ATTRIB_ARRAY7_NV
_m[0x8658] = (1,) # GL_VERTEX_ATTRIB_ARRAY8_NV
_m[0x8659] = (1,) # GL_VERTEX_ATTRIB_ARRAY9_NV
_m[0x889F] = (1,) # GL_VERTEX_ATTRIB_ARRAY_BUFFER_BINDING
_m[0x889F] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/vertex_buffer_object.txt # GL_VERTEX_ATTRIB_ARRAY_BUFFER_BINDING_ARB
_m[0x88FE] = (1,) # GL_VERTEX_ATTRIB_ARRAY_DIVISOR
_m[0x8622] = (1,) # GL_VERTEX_ATTRIB_ARRAY_ENABLED
_m[0x88FD] = (1,) # GL_VERTEX_ATTRIB_ARRAY_INTEGER
_m[0x886A] = (1,) # GL_VERTEX_ATTRIB_ARRAY_NORMALIZED
_m[0x8645] = (1,) # GL_VERTEX_ATTRIB_ARRAY_POINTER
_m[0x8623] = (1,) # GL_VERTEX_ATTRIB_ARRAY_SIZE
_m[0x8624] = (1,) # GL_VERTEX_ATTRIB_ARRAY_STRIDE
_m[0x8625] = (1,) # GL_VERTEX_ATTRIB_ARRAY_TYPE
_m[0x82D4] = (1,) # GL_VERTEX_ATTRIB_BINDING
_m[0x82D5] = (1,) # GL_VERTEX_ATTRIB_RELATIVE_OFFSET
_m[0x82D6] = (1,) # GL_VERTEX_BINDING_DIVISOR
_m[0x82D7] = (1,) # GL_VERTEX_BINDING_OFFSET
_m[0x82D8] = (1,) # GL_VERTEX_BINDING_STRIDE
_m[0x86A7] = (1,) # GL_VERTEX_BLEND_ARB
_m[0x83EF] = (1,) # GL_VERTEX_PRECLIP_HINT_SGIX
_m[0x83EE] = (1,) # GL_VERTEX_PRECLIP_SGIX
_m[0x8620] = (1,) # GL_VERTEX_PROGRAM_ARB
_m[0x864A] = (1,) # GL_VERTEX_PROGRAM_BINDING_NV
_m[0x8620] = (1,) # GL_VERTEX_PROGRAM_NV
_m[0x8DA2] = (1,) # GL_VERTEX_PROGRAM_PARAMETER_BUFFER_NV
_m[0x8642] = (1,) # GL_VERTEX_PROGRAM_POINT_SIZE
_m[0x8642] = (1,) # GL_VERTEX_PROGRAM_POINT_SIZE_ARB
_m[0x8642] = (1,) # GL_VERTEX_PROGRAM_POINT_SIZE_NV
_m[0x8643] = (1,) # GL_VERTEX_PROGRAM_TWO_SIDE
_m[0x8643] = (1,) # GL_VERTEX_PROGRAM_TWO_SIDE_ARB
_m[0x8643] = (1,) # GL_VERTEX_PROGRAM_TWO_SIDE_NV
_m[0x8B31] = (1,) # GL_VERTEX_SHADER
_m[0x8781] = (1,) # GL_VERTEX_SHADER_BINDING_EXT
_m[0x8780] = (1,) # GL_VERTEX_SHADER_EXT
_m[0x87CF] = (1,) # GL_VERTEX_SHADER_INSTRUCTIONS_EXT
_m[0x87D1] = (1,) # GL_VERTEX_SHADER_INVARIANTS_EXT
_m[0x87D3] = (1,) # GL_VERTEX_SHADER_LOCALS_EXT
_m[0x87D2] = (1,) # GL_VERTEX_SHADER_LOCAL_CONSTANTS_EXT
_m[0x87D4] = (1,) # GL_VERTEX_SHADER_OPTIMIZED_EXT
_m[0x87D0] = (1,) # GL_VERTEX_SHADER_VARIANTS_EXT
_m[0x829B] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_VERTEX_TEXTURE
_m[0x850C] = (1,) # GL_VERTEX_WEIGHT_ARRAY_EXT
_m[0x8510] = (1,) # GL_VERTEX_WEIGHT_ARRAY_POINTER_EXT
_m[0x850D] = (1,) # GL_VERTEX_WEIGHT_ARRAY_SIZE_EXT
_m[0x850F] = (1,) # GL_VERTEX_WEIGHT_ARRAY_STRIDE_EXT
_m[0x850E] = (1,) # GL_VERTEX_WEIGHT_ARRAY_TYPE_EXT
_m[0x8719] = (1,) # GL_VIBRANCE_BIAS_NV
_m[0x8713] = (1,) # GL_VIBRANCE_SCALE_NV
_m[0x9021] = (1,) # GL_VIDEO_BUFFER_BINDING_NV
_m[0x0BA2] = (4,) # GL_VIEWPORT
_m[0x825D] = (2,) # GL_VIEWPORT_BOUNDS_RANGE
_m[0x825F] = (1,) # GL_VIEWPORT_INDEX_PROVOKING_VERTEX
_m[0x825C] = (1,) # GL_VIEWPORT_SUBPIXEL_BITS
_m[0x82B6] = (1,)#TODO Review http://www.opengl.org/registry/specs//ARB/internalformat_query2.txt # GL_VIEW_COMPATIBILITY_CLASS
_m[0x933A] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/shader_thread_group.txt # GL_WARPS_PER_SM_NV
_m[0x9339] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/shader_thread_group.txt # GL_WARP_SIZE_NV
_m[0x86AD] = (1,) # GL_WEIGHT_ARRAY_ARB
_m[0x889E] = (1,) # GL_WEIGHT_ARRAY_BUFFER_BINDING
_m[0x889E] = (1,) # GL_WEIGHT_ARRAY_BUFFER_BINDING_ARB
_m[0x86AC] = (1,) # GL_WEIGHT_ARRAY_POINTER_ARB
_m[0x86AB] = (1,) # GL_WEIGHT_ARRAY_SIZE_ARB
_m[0x86AA] = (1,) # GL_WEIGHT_ARRAY_STRIDE_ARB
_m[0x86A9] = (1,) # GL_WEIGHT_ARRAY_TYPE_ARB
_m[0x86A6] = (1,) # GL_WEIGHT_SUM_UNITY_ARB
_m[0x887A] = (1,) # GL_WRITE_PIXEL_DATA_RANGE_LENGTH_NV
_m[0x887C] = (1,)#TODO Review http://www.opengl.org/registry/specs//NV/pixel_data_range.txt # GL_WRITE_PIXEL_DATA_RANGE_POINTER_NV
_m[0x0D16] = (1,) # GL_ZOOM_X
_m[0x0D17] = (1,) # GL_ZOOM_Y
